-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amx/fixpack2/etl/sql/AMX_c05_s010_rim_extract.db2, tmnt_etl, tmnt_5.1.1, 511ITM04C
-- #   Revision: 1.1
-- #   Date: 11/25/02 17:33:26
-- ############################################################################

----------------------------------------------------
-- Replicate data from ITM central repository to CDW
----------------------------------------------------

-------------------------
-- AMX table:  RmProfiles
-------------------------

--#IGNORE_ERROR
DROP TABLE TMP_EXT_CONTROL
;
--
-- create table to hold the extract window
--
CREATE TABLE TMP_EXT_CONTROL (
  EXTCTL_FROM_INTSEQ  BIGINT,
  EXTCTL_TO_INTSEQ    BIGINT )
;
--
-- //////////////// get the from_intseq from the extract_control in the CDW
-- //////////////// from: TWH_CDW to: ITM_DB
--
--#INSERT_INTO_SOURCE
INSERT INTO TMP_EXT_CONTROL
SELECT 
EXTCTL_FROM_INTSEQ,
-1
FROM 
TWG.EXTRACT_CONTROL
WHERE
EXTCTL_SOURCE='RMPROFILES' AND
EXTCTL_TARGET='AMX.STAGE1_RMPROFILES' 
;
--
-- //////////////// update with the max twh_insert_seq
-- //////////////// at: ITM_DB
--
UPDATE TMP_EXT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT MAX(INSERT_SEQ) FROM RMPROFILES)
WHERE 0 < (SELECT COUNT(*) FROM RMPROFILES)
;
--
-- //////////////// drop the stage1 table in twh_cdw
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.STAGE1_RMPROFILES (
  CATEGORY        VARCHAR(128),
  PROFILE         VARCHAR(255),
  RESOURCE_MODEL  VARCHAR(128),
  ID              BIGINT NOT NULL,
  EID             INTEGER NOT NULL,
    PRIMARY KEY (ID, EID)
);
--#INSERT_INTO_TARGET
INSERT INTO AMX.STAGE1_RMPROFILES  
SELECT 
 O.CATEGORY,
 O.PROFILE,
 O.RESOURCE_MODEL,
 O.ID,		
 O.EID
FROM 
 RMPROFILES O,
 TMP_EXT_CONTROL EC
WHERE
 O.INSERT_SEQ > EC.EXTCTL_FROM_INTSEQ AND
 O.INSERT_SEQ <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////////////// drop to_intseq temp table in CDW
-- //////////////// at: TWH_CDW 
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMX.TEMP_TO_INTSEQ
;
--
-- //////////////// create to_intseq temp table in CDW
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.TEMP_TO_INTSEQ (
  EXTCTL_TO_INTSEQ   BIGINT ) 
;
--
-- //////////////// copy to_intseq value into temp table in CDW
-- //////////////// from: ITM_DB to: TWH_CDW
--
--#INSERT_INTO_TARGET
INSERT INTO AMX.TEMP_TO_INTSEQ 
SELECT EXTCTL_TO_INTSEQ FROM TMP_EXT_CONTROL
;
--
-- //////////////// update extract control with to_intseq value
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
UPDATE TWG.EXTRACT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT EXTCTL_TO_INTSEQ FROM AMX.TEMP_TO_INTSEQ)
WHERE
EXTCTL_SOURCE='RMPROFILES' AND
EXTCTL_TARGET='AMX.STAGE1_RMPROFILES'
;
--
-- //////////////// write extract info to extract log
-- //////////////// this fires the trigger that updates extract control to close the window
-- 
--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'RMPROFILES' AND
 EC.EXTCTL_TARGET = 'AMX.STAGE1_RMPROFILES'
; 

------------------------
-- AMX table:  Resources
------------------------

--#IGNORE_ERROR
DROP TABLE TMP_EXT_CONTROL
;
--
-- create table to hold the extract window
--
CREATE TABLE TMP_EXT_CONTROL (
  EXTCTL_FROM_INTSEQ  BIGINT,
  EXTCTL_TO_INTSEQ    BIGINT )
;
--
-- //////////////// get the from_intseq from the extract_control in the CDW
-- //////////////// from: TWH_CDW to: ITM_DB
--
--#INSERT_INTO_SOURCE
INSERT INTO TMP_EXT_CONTROL
SELECT 
EXTCTL_FROM_INTSEQ,
-1
FROM 
TWG.EXTRACT_CONTROL
WHERE
EXTCTL_SOURCE='RESOURCES' AND
EXTCTL_TARGET='AMX.STAGE1_RESOURCES' 
;
--
-- //////////////// update with the max twh_insert_seq
-- //////////////// at: ITM_DB
--
UPDATE TMP_EXT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT MAX(INSERT_SEQ) FROM RESOURCES)
WHERE 0 < (SELECT COUNT(*) FROM RESOURCES)
;
--
-- //////////////// drop the stage table in twh_cdw
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.STAGE1_RESOURCES (
  RESOURCE  VARCHAR(128),
  CONTEXT   VARCHAR(255),
  RCID      BIGINT NOT NULL,
  ID        BIGINT NOT NULL,
  EID	     INTEGER NOT NULL,	
    PRIMARY KEY (RCID, EID)
);
--#INSERT_INTO_TARGET
INSERT INTO AMX.STAGE1_RESOURCES  
SELECT 
 O.RESOURC,
 O.CONTEXT,
 O.RCID,		
 O.ID,
 O.EID 
FROM 
 RESOURCES O,
 TMP_EXT_CONTROL EC
WHERE
 O.INSERT_SEQ > EC.EXTCTL_FROM_INTSEQ AND
 O.INSERT_SEQ <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////////////// drop to_intseq temp table in CDW
-- //////////////// at: TWH_CDW 
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMX.TEMP_TO_INTSEQ
;
--
-- //////////////// create to_intseq temp table in CDW
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.TEMP_TO_INTSEQ (
  EXTCTL_TO_INTSEQ   BIGINT ) 
;
--
-- //////////////// copy to_intseq value into temp table in CDW
-- //////////////// from: ITM_DB to: TWH_CDW
--
--#INSERT_INTO_TARGET
INSERT INTO AMX.TEMP_TO_INTSEQ 
SELECT EXTCTL_TO_INTSEQ FROM TMP_EXT_CONTROL
;
--
-- //////////////// update extract control with to_intseq value
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
UPDATE TWG.EXTRACT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT EXTCTL_TO_INTSEQ FROM AMX.TEMP_TO_INTSEQ)
WHERE
EXTCTL_SOURCE='RESOURCES' AND
EXTCTL_TARGET='AMX.STAGE1_RESOURCES' 
;
--
-- //////////////// write extract info to extract log
-- //////////////// this fires the trigger that updates extract control to close the window
-- 
--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'RESOURCES' AND
 EC.EXTCTL_TARGET = 'AMX.STAGE1_RESOURCES'
; 

-----------------------
-- AMX table:  Instance
-----------------------

--#IGNORE_ERROR
DROP TABLE TMP_EXT_CONTROL
;
--
-- create table to hold the extract window
--
CREATE TABLE TMP_EXT_CONTROL (
  EXTCTL_FROM_INTSEQ  BIGINT,
  EXTCTL_TO_INTSEQ    BIGINT )
;
--
-- //////////////// get the from_intseq from the extract_control in the CDW
-- //////////////// from: TWH_CDW to: ITM_DB
--
--#INSERT_INTO_SOURCE
INSERT INTO TMP_EXT_CONTROL
SELECT 
EXTCTL_FROM_INTSEQ,
-1
FROM 
TWG.EXTRACT_CONTROL
WHERE
EXTCTL_SOURCE='INSTANCES' AND
EXTCTL_TARGET='AMX.STAGE1_INSTANCES' 
;
--
-- //////////////// update with the max twh_insert_seq
-- //////////////// at: ITM_DB
--
UPDATE TMP_EXT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT MAX(INSERT_SEQ) FROM INSTANCES)
WHERE 0 < (SELECT COUNT(*) FROM INSTANCES)
;
--
-- //////////////// drop the stage table in twh_cdw
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.STAGE1_INSTANCES (
  INSTANCE_KEY  VARCHAR(2096),
  IID           BIGINT NOT NULL,
  RCID          BIGINT NOT NULL,
  EID           INTEGER NOT NULL,
    PRIMARY KEY (IID,EID)
);
--#INSERT_INTO_TARGET
INSERT INTO AMX.STAGE1_INSTANCES  
SELECT 
 O.INSTANCE_KEY,
 O.IID,
 O.RCID,		
 O.EID
FROM 
 INSTANCES O,
 TMP_EXT_CONTROL EC
WHERE
 O.INSERT_SEQ > EC.EXTCTL_FROM_INTSEQ AND
 O.INSERT_SEQ <= EC.EXTCTL_TO_INTSEQ  
;
--
-- //////////////// drop to_intseq temp table in CDW
-- //////////////// at: TWH_CDW 
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMX.TEMP_TO_INTSEQ
;
--
-- //////////////// create to_intseq temp table in CDW
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.TEMP_TO_INTSEQ (
  EXTCTL_TO_INTSEQ   BIGINT ) 
;
--
-- //////////////// copy to_intseq value into temp table in CDW
-- //////////////// from: ITM_DB to: TWH_CDW
--
--#INSERT_INTO_TARGET
INSERT INTO AMX.TEMP_TO_INTSEQ 
SELECT EXTCTL_TO_INTSEQ FROM TMP_EXT_CONTROL
;
--
-- //////////////// update extract control with to_intseq value
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
UPDATE TWG.EXTRACT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT EXTCTL_TO_INTSEQ FROM AMX.TEMP_TO_INTSEQ)
WHERE
EXTCTL_SOURCE='INSTANCES' AND
EXTCTL_TARGET='AMX.STAGE1_INSTANCES' 
;
--
-- //////////////// write extract info to extract log
-- //////////////// this fires the trigger that updates extract control to close the window
-- 
--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'INSTANCES' AND
 EC.EXTCTL_TARGET = 'AMX.STAGE1_INSTANCES'
; 

----------------------
-- AMX table:  Metrics
----------------------

--#IGNORE_ERROR
DROP TABLE TMP_EXT_CONTROL
;
--
-- create table to hold the extract window
--
CREATE TABLE TMP_EXT_CONTROL (
  EXTCTL_FROM_INTSEQ  BIGINT,
  EXTCTL_TO_INTSEQ    BIGINT )
;
--
-- //////////////// get the from_intseq from the extract_control in the CDW
-- //////////////// from: TWH_CDW to: ITM_DB
--
--#INSERT_INTO_SOURCE
INSERT INTO TMP_EXT_CONTROL
SELECT 
EXTCTL_FROM_INTSEQ,
-1
FROM 
TWG.EXTRACT_CONTROL
WHERE
EXTCTL_SOURCE='METRICS' AND
EXTCTL_TARGET='AMX.STAGE1_METRICS' 
;
--
-- //////////////// update with the max twh_insert_seq
-- //////////////// at: ITM_DB
--
UPDATE TMP_EXT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT MAX(INSERT_SEQ) FROM METRICS)
WHERE 0 < (SELECT COUNT(*) FROM METRICS)
;
--
-- //////////////// drop the stage table in twh_cdw
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.STAGE1_METRICS (
  NAME  VARCHAR(128),
  RCID  BIGINT NOT NULL,
  MID   BIGINT NOT NULL,
  STAT  VARCHAR(8),
  EID   INTEGER NOT NULL,
    PRIMARY KEY (MID,EID)
);
--#INSERT_INTO_TARGET
INSERT INTO AMX.STAGE1_METRICS  
SELECT 
 O.NAME,
 O.RCID,		
 O.MID,
 O.STAT,
 O.EID
FROM 
 METRICS O,
 TMP_EXT_CONTROL EC
WHERE
 O.INSERT_SEQ > EC.EXTCTL_FROM_INTSEQ AND
 O.INSERT_SEQ <= EC.EXTCTL_TO_INTSEQ
;
--
-- //////////////// drop to_intseq temp table in CDW
-- //////////////// at: TWH_CDW 
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMX.TEMP_TO_INTSEQ
;
--
-- //////////////// create to_intseq temp table in CDW
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.TEMP_TO_INTSEQ (
  EXTCTL_TO_INTSEQ   BIGINT ) 
;
--
-- //////////////// copy to_intseq value into temp table in CDW
-- //////////////// from: ITM_DB to: TWH_CDW
--
--#INSERT_INTO_TARGET
INSERT INTO AMX.TEMP_TO_INTSEQ 
SELECT EXTCTL_TO_INTSEQ FROM TMP_EXT_CONTROL
;
--
-- //////////////// update extract control with to_intseq value
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
UPDATE TWG.EXTRACT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT EXTCTL_TO_INTSEQ FROM AMX.TEMP_TO_INTSEQ)
WHERE
EXTCTL_SOURCE='METRICS' AND
EXTCTL_TARGET='AMX.STAGE1_METRICS' 
;
--
-- //////////////// write extract info to extract log
-- //////////////// this fires the trigger that updates extract control to close the window
-- 
--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'METRICS' AND
 EC.EXTCTL_TARGET = 'AMX.STAGE1_METRICS'
; 

--------------------------
-- AMX table:  MetricsData
--------------------------

--#IGNORE_ERROR
DROP TABLE TMP_EXT_CONTROL
;
--
-- create table to hold the extract window
--
CREATE TABLE TMP_EXT_CONTROL (
  EXTCTL_FROM_INTSEQ  BIGINT,
  EXTCTL_TO_INTSEQ    BIGINT )
;
--
-- //////////////// get the from_intseq from the extract_control in the CDW
-- //////////////// from: TWH_CDW to: ITM_DB
--
--#INSERT_INTO_SOURCE
INSERT INTO TMP_EXT_CONTROL
SELECT 
EXTCTL_FROM_INTSEQ,
-1
FROM 
TWG.EXTRACT_CONTROL
WHERE
EXTCTL_SOURCE='METRICSDATA' AND
EXTCTL_TARGET='AMX.STAGE_METRICSDATA' 
;
--
-- //////////////// update with the max twh_insert_seq
-- //////////////// at: ITM_DB
--
UPDATE TMP_EXT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT MAX(INSERT_SEQ) FROM METRICSDATA)
WHERE 0 < (SELECT COUNT(*) FROM METRICSDATA)
;
--
-- //////////////// drop the stage table in twh_cdw
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.STAGE_METRICSDATA ( 
  MID           BIGINT NOT NULL,
  METRICVALUE   FLOAT NOT NULL,
  TIMEKEY_DTTM  TIMESTAMP NOT NULL,
  IID           BIGINT NOT NULL,
  EID           INTEGER NOT NULL,
    PRIMARY KEY (MID, TIMEKEY_DTTM, IID, EID)
);
--#INSERT_INTO_TARGET
INSERT INTO AMX.STAGE_METRICSDATA  
SELECT 
 O.MID,
 O.METRICVALUE,
 O.TIMEKEY_DTTM,
 O.IID,		
 O.EID
FROM 
 METRICSDATA O,
 TMP_EXT_CONTROL EC
WHERE
 O.INSERT_SEQ > EC.EXTCTL_FROM_INTSEQ AND
 O.INSERT_SEQ <= EC.EXTCTL_TO_INTSEQ
;
--
-- //////////////// drop to_intseq temp table in CDW
-- //////////////// at: TWH_CDW 
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMX.TEMP_TO_INTSEQ
;
--
-- //////////////// create to_intseq temp table in CDW
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.TEMP_TO_INTSEQ (
  EXTCTL_TO_INTSEQ   BIGINT ) 
;
--
-- //////////////// copy to_intseq value into temp table in CDW
-- //////////////// from: ITM_DB to: TWH_CDW
--
--#INSERT_INTO_TARGET
INSERT INTO AMX.TEMP_TO_INTSEQ 
SELECT EXTCTL_TO_INTSEQ FROM TMP_EXT_CONTROL
;
--
-- //////////////// update extract control with to_intseq value
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
UPDATE TWG.EXTRACT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT EXTCTL_TO_INTSEQ FROM AMX.TEMP_TO_INTSEQ)
WHERE
EXTCTL_SOURCE='METRICSDATA' AND
EXTCTL_TARGET='AMX.STAGE_METRICSDATA'
;
--
-- //////////////// write extract info to extract log
-- //////////////// this fires the trigger that updates extract control to close the window
-- 
--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'METRICSDATA' AND
 EC.EXTCTL_TARGET = 'AMX.STAGE_METRICSDATA'
; 

-------------------------
-- AMX table:  Categories
-------------------------

--#IGNORE_ERROR
DROP TABLE TMP_EXT_CONTROL
;
--
-- create table to hold the extract window
--
CREATE TABLE TMP_EXT_CONTROL (
  EXTCTL_FROM_INTSEQ  BIGINT,
  EXTCTL_TO_INTSEQ    BIGINT )
;
--
-- //////////////// get the from_intseq from the extract_control in the CDW
-- //////////////// from: TWH_CDW to: ITM_DB
--
--#INSERT_INTO_SOURCE
INSERT INTO TMP_EXT_CONTROL
SELECT 
EXTCTL_FROM_INTSEQ,
-1
FROM 
TWG.EXTRACT_CONTROL
WHERE
EXTCTL_SOURCE='CATEGORIES' AND
EXTCTL_TARGET='AMX.STAGE1_CATEGORIES' 
;
--
-- //////////////// update with the max twh_insert_seq
-- //////////////// at: ITM_DB
--
UPDATE TMP_EXT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT MAX(INSERT_SEQ) FROM CATEGORIES)
WHERE 0 < (SELECT COUNT(*) FROM CATEGORIES)
;
--
-- //////////////// drop the stage table in twh_cdw
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.STAGE1_CATEGORIES (
  NAME  VARCHAR(128),
  RCID  BIGINT NOT NULL,
  CID   BIGINT NOT NULL,
  EID   INTEGER NOT NULL,
    PRIMARY KEY (CID,EID)
);
--#INSERT_INTO_TARGET
INSERT INTO AMX.STAGE1_CATEGORIES  
SELECT 
 O.NAME,
 O.RCID,		
 O.CID,
 O.EID
FROM 
 CATEGORIES O,
 TMP_EXT_CONTROL EC
WHERE
 O.INSERT_SEQ > EC.EXTCTL_FROM_INTSEQ AND
 O.INSERT_SEQ <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////////////// drop to_intseq temp table in CDW
-- //////////////// at: TWH_CDW 
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMX.TEMP_TO_INTSEQ
;
--
-- //////////////// create to_intseq temp table in CDW
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.TEMP_TO_INTSEQ (
  EXTCTL_TO_INTSEQ   BIGINT ) 
;
--
-- //////////////// copy to_intseq value into temp table in CDW
-- //////////////// from: ITM_DB to: TWH_CDW
--
--#INSERT_INTO_TARGET
INSERT INTO AMX.TEMP_TO_INTSEQ 
SELECT EXTCTL_TO_INTSEQ FROM TMP_EXT_CONTROL
;
--
-- //////////////// update extract control with to_intseq value
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
UPDATE TWG.EXTRACT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT EXTCTL_TO_INTSEQ FROM AMX.TEMP_TO_INTSEQ)
WHERE
EXTCTL_SOURCE='CATEGORIES' AND
EXTCTL_TARGET='AMX.STAGE1_CATEGORIES'
;
--
-- //////////////// write extract info to extract log
-- //////////////// this fires the trigger that updates extract control to close the window
-- 
--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'CATEGORIES' AND
 EC.EXTCTL_TARGET = 'AMX.STAGE1_CATEGORIES'
; 

-----------------------------
-- AMX table:  CategoriesData
-----------------------------

--#IGNORE_ERROR
DROP TABLE TMP_EXT_CONTROL
;
--
-- create table to hold the extract window
--
CREATE TABLE TMP_EXT_CONTROL (
  EXTCTL_FROM_INTSEQ  BIGINT,
  EXTCTL_TO_INTSEQ    BIGINT )
;
--
-- //////////////// get the from_intseq from the extract_control in the CDW
-- //////////////// from: TWH_CDW to: ITM_DB
--
--#INSERT_INTO_SOURCE
INSERT INTO TMP_EXT_CONTROL
SELECT 
EXTCTL_FROM_INTSEQ,
-1
FROM 
TWG.EXTRACT_CONTROL
WHERE
EXTCTL_SOURCE='CATEGORIESDATA' AND
EXTCTL_TARGET='AMX.STAGE_CATEGORIESDATA' 
;
--
-- //////////////// update with the max twh_insert_seq
-- //////////////// at: ITM_DB
--
UPDATE TMP_EXT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT MAX(INSERT_SEQ) FROM CATEGORIESDATA)
WHERE 0 < (SELECT COUNT(*) FROM CATEGORIESDATA)
;
--
-- //////////////// drop the stage table in twh_cdw
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.STAGE_CATEGORIESDATA (
  CID            BIGINT NOT NULL,
  CATEGORYVALUE  VARCHAR(128),
  TIMEKEY_DTTM   TIMESTAMP NOT NULL,
  IID            BIGINT NOT NULL,
  EID            INTEGER NOT NULL,
    PRIMARY KEY (CID,TIMEKEY_DTTM,IID,EID)
);
--#INSERT_INTO_TARGET
INSERT INTO AMX.STAGE_CATEGORIESDATA  
SELECT 
 O.CID,
 O.CATEGORYVALUE,
 O.TIMEKEY_DTTM,
 O.IID,		
 O.EID
FROM 
 CATEGORIESDATA O,
 TMP_EXT_CONTROL EC
WHERE
 O.INSERT_SEQ > EC.EXTCTL_FROM_INTSEQ AND
 O.INSERT_SEQ <= EC.EXTCTL_TO_INTSEQ  
;
--
-- //////////////// drop to_intseq temp table in CDW
-- //////////////// at: TWH_CDW 
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMX.TEMP_TO_INTSEQ
;
--
-- //////////////// create to_intseq temp table in CDW
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.TEMP_TO_INTSEQ (
  EXTCTL_TO_INTSEQ   BIGINT ) 
;
--
-- //////////////// copy to_intseq value into temp table in CDW
-- //////////////// from: ITM_DB to: TWH_CDW
--
--#INSERT_INTO_TARGET
INSERT INTO AMX.TEMP_TO_INTSEQ 
SELECT EXTCTL_TO_INTSEQ FROM TMP_EXT_CONTROL
;
--
-- //////////////// update extract control with to_intseq value
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
UPDATE TWG.EXTRACT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT EXTCTL_TO_INTSEQ FROM AMX.TEMP_TO_INTSEQ)
WHERE
EXTCTL_SOURCE='CATEGORIESDATA' AND
EXTCTL_TARGET='AMX.STAGE_CATEGORIESDATA'
;
--
-- //////////////// write extract info to extract log
-- //////////////// this fires the trigger that updates extract control to close the window
-- 
--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'CATEGORIESDATA' AND
 EC.EXTCTL_TARGET = 'AMX.STAGE_CATEGORIESDATA'
; 

------------------------
-- AMX table:  Endpoints
------------------------

--#IGNORE_ERROR
DROP TABLE TMP_EXT_CONTROL
;
--
-- create table to hold the extract window
--
CREATE TABLE TMP_EXT_CONTROL (
  EXTCTL_FROM_INTSEQ  BIGINT,
  EXTCTL_TO_INTSEQ    BIGINT )
;
--
-- //////////////// get the from_intseq from the extract_control in the CDW
-- //////////////// from: TWH_CDW to: ITM_DB
--
--#INSERT_INTO_SOURCE
INSERT INTO TMP_EXT_CONTROL
SELECT 
EXTCTL_FROM_INTSEQ,
-1
FROM 
TWG.EXTRACT_CONTROL
WHERE
EXTCTL_SOURCE='ENDPOINTS' AND
EXTCTL_TARGET='AMX.STAGE_ENDPOINTS' 
;
--
-- //////////////// update with the max twh_insert_seq
-- //////////////// at: ITM_DB
--
UPDATE TMP_EXT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT MAX(EID) FROM ENDPOINTS)
WHERE 0 < (SELECT COUNT(*) FROM ENDPOINTS)
;
--
-- //////////////// drop the stage table in twh_cdw
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.STAGE_ENDPOINTS (
  EID             INTEGER NOT NULL,
  HOST_NM         VARCHAR(120),
  IP_ADDR         VARCHAR(20),
  ENDPOINT_LABEL  VARCHAR(64),
  GMT_OFFSET      INTEGER NOT NULL,
    PRIMARY KEY (EID)
);
--#INSERT_INTO_TARGET
INSERT INTO AMX.STAGE_ENDPOINTS  
SELECT 
 O.EID,
 O.HOST_NAME,
 O.IP_ADDRESS AS IP_ADDR,
 O.ENDPOINT_LABEL AS ENDPOINT_LABEL,
 O.GMT_OFFSET AS GMT_OFFSET
FROM 
 ENDPOINTS O,
 TMP_EXT_CONTROL EC
WHERE
 O.EID > EC.EXTCTL_FROM_INTSEQ AND
 O.EID <= EC.EXTCTL_TO_INTSEQ  
;
--
-- //////////////// drop to_intseq temp table in CDW
-- //////////////// at: TWH_CDW 
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMX.TEMP_TO_INTSEQ
;
--
-- //////////////// create to_intseq temp table in CDW
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMX.TEMP_TO_INTSEQ (
  EXTCTL_TO_INTSEQ   BIGINT ) 
;
--
-- //////////////// copy to_intseq value into temp table in CDW
-- //////////////// from: ITM_DB to: TWH_CDW
--
--#INSERT_INTO_TARGET
INSERT INTO AMX.TEMP_TO_INTSEQ 
SELECT EXTCTL_TO_INTSEQ FROM TMP_EXT_CONTROL
;
--
-- //////////////// update extract control with to_intseq value
-- //////////////// at: TWH_CDW
--
--#EXECUTE_AT_TARGET
UPDATE TWG.EXTRACT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT EXTCTL_TO_INTSEQ FROM AMX.TEMP_TO_INTSEQ)
WHERE
EXTCTL_SOURCE='ENDPOINTS' AND
EXTCTL_TARGET='AMX.STAGE_ENDPOINTS' 
;
--
-- //////////////// write extract info to extract log
-- //////////////// this fires the trigger that updates extract control to close the window
-- 
--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'ENDPOINTS' AND
 EC.EXTCTL_TARGET = 'AMX.STAGE_ENDPOINTS'
;

