-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amx/fixpack2/etl/sql/AMX_c10_s010_Rim_Prune.db2, tmnt_etl, tmnt_5.1.1, 511ITM04C
-- #   Revision: 1.1
-- #   Date: 11/25/02 17:34:10
-- ############################################################################

--
-- //////// display the content of the prune_control table as
-- //////// resulting from the previous run of the prune process...
--
--#EXECUTE_AT_TARGET
SELECT * FROM AMX.PRUNE_CONTROL
;

-- NOTE: the timekey in the Middle Layer database is expressed as
-- the number of seconds since the epoch (in GMT time), so we must
-- find the timekey that is n days less than now...

--#EXECUTE_AT_TARGET
UPDATE AMX.PRUNE_CONTROL SET
PRUNE_KEY = 
86400 * ( DAYS(DATE(CURRENT TIMESTAMP - CURRENT TIMEZONE)) - DAYS('01/01/1970') 
          - (SELECT AGE_DAYS FROM AMX.PRUNE_CONTROL) 
        ) + MIDNIGHT_SECONDS(CURRENT TIME - CURRENT TIMEZONE)
;

--#IGNORE_ERROR
DROP TABLE TEMP_PRUNE_KEY
;

CREATE TABLE TEMP_PRUNE_KEY (
  PRUNE_KEY   INTEGER )
;

--#INSERT_INTO_SOURCE
INSERT INTO TEMP_PRUNE_KEY
  SELECT PRUNE_KEY FROM AMX.PRUNE_CONTROL
;
--
-- //////// display the rows that will be deleted...
--
SELECT
  DISTINCT TIMEKEY,TIMEKEY_DTTM FROM METRICSDATA
WHERE
  TIMEKEY < (
     SELECT PRUNE_KEY FROM TEMP_PRUNE_KEY )
;
--
-- //////// delete all records from MetricsData older 
-- //////// than prune_key seconds since the epoch...
--
DELETE FROM METRICSDATA
WHERE TIMEKEY < (SELECT PRUNE_KEY FROM TEMP_PRUNE_KEY)
;
--
-- //////// display the rows that will be deleted...
--
SELECT
  DISTINCT TIMEKEY,TIMEKEY_DTTM FROM CATEGORIESDATA
WHERE
  TIMEKEY < (
     SELECT PRUNE_KEY FROM TEMP_PRUNE_KEY )
;
--
-- //////// delete all records from CategoriesData older 
-- //////// than prune_key seconds since the epoch...
--
DELETE FROM CATEGORIESDATA
WHERE TIMEKEY < (SELECT PRUNE_KEY FROM TEMP_PRUNE_KEY)
;

-- NOTE: all the DML statements below are fixed (constant), they 
-- simply relies on the results of the previous two DML statements, 
-- which purge data from MetricsData and CategoriesData tables 
-- according to the TIMEKEY parameter...

--
-- //////// delete all records from Metrics that are 
-- //////// no more referenced by the MetricsData table
--
DELETE FROM METRICS
WHERE MID NOT IN (SELECT DISTINCT MID FROM METRICSDATA)
;
--
-- //////// delete all records from Categories 
-- //////// no more referenced by the CategoriesData table
--
DELETE FROM CATEGORIES
WHERE CID NOT IN (SELECT DISTINCT CID FROM CATEGORIESDATA)
;
--
-- //////// delete all records from Instances that are
-- //////// no more referenced by the CategoriesData and 
-- //////// MetricsData tables
--
DELETE FROM INSTANCES
WHERE IID NOT IN (SELECT DISTINCT IID FROM CATEGORIESDATA) AND
      IID NOT IN (SELECT DISTINCT IID FROM METRICSDATA)
;
--
-- //////// delete all records from Resources that are
-- //////// no more referenced by the Metrics, Categories
-- //////// and Instances tables
--
DELETE FROM RESOURCES
WHERE RCID NOT IN (SELECT DISTINCT RCID FROM METRICS) AND
      RCID NOT IN (SELECT DISTINCT RCID FROM CATEGORIES) AND
      RCID NOT IN (SELECT DISTINCT RCID FROM INSTANCES)
;
--
-- //////// delete all records from RmProfiles that are 
-- //////// no more referenced by the Resources table
--
DELETE FROM RMPROFILES
WHERE ID NOT IN (SELECT DISTINCT ID FROM RESOURCES)
;
--
-- //////// delete all records from Endpoints that are 
-- //////// no more referenced by the RmProfiles table
--
--DELETE FROM ENDPOINTS
--WHERE EID NOT IN (SELECT DISTINCT EID FROM RMPROFILES)
--;
--
-- //////// record the successful prune (time fields are in UTC)...
--
--#EXECUTE_AT_TARGET
INSERT INTO AMX.PRUNE_LOG
SELECT
  CURRENT TIMESTAMP - CURRENT TIMEZONE,
  AGE_DAYS,
  PRUNE_KEY,
  TIMESTAMP( DATE('01/01/1970') + INTEGER(PRUNE_KEY/86400) DAYS , 
    TIME('00.00.00') + (PRUNE_KEY - (86400 * (INTEGER(PRUNE_KEY/86400)))) SECOND )
FROM
  AMX.PRUNE_CONTROL
;
--
-- //////// show the resulting prune log...
--
--#EXECUTE_AT_TARGET
SELECT * FROM AMX.PRUNE_LOG
;

