#!/bin/sh
############################################################################
#
#  Licensed Materials - Property of IBM
#  Product ID = 5724-C04
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: Common/src/tedw_app/amx/fixpack2/misc/amx_after.sh, tmnt_etl, tmnt_5.1.1, 511ITM04C
#   Revision: 1.1
#   Date: 11/25/02 17:35:04
############################################################################

############################################################################
# Command Line Args:
#	1 = the path and name of the TWH Application config file
#	2 = Application working directory or install base directory
#		$TWH_TOPDIR/apps/ava_code_for_app/vapp_version (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this script called amx_after.sh.log
#
# Required Env Vars:
#       None.
#
# Return Codes:
#	0 = Success
#	255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#       6 - TWH Core tools and application components must be
#	      successfully installed
#
# What is accomplished:
#  * Copy the AMX_Create_Comp_Msmt.sh into $TWH_TOPDIR/tools/bin
#
# Note - Caution needs to be taken for NT paths that have a space.  This
#        is a limitation that requires double quoting around all 
#	   variables that contain a path.  Testing should be done to ensure
#	   this script runs with a space in any of the paths that are used.
#########################################################################
#


###
echo "        ** After Script Log **          "
echo ""
echo "****************************************"
echo "* Application After Script Start point *"
echo "****************************************"
echo ""

# Pulls in the generic shared routines

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Execute startup driver for afterscript
. "$TWH_TOPDIR"/install/bin/twh_core_startup_after.sh
exec_startup_driver;

#####################################################
######## Add application code below here ONLY #######
#####################################################

#
set_amx_program_vars()
{
AMX_MISC_DIR="$APP_WORK_DIR/misc"     # path to bash script to be copied
tmp_sql_file="amx_tmp_sql.sql"        # name of the temporary sql file

TRUE=1
FALSE=0

return 0;
}


###


# Prevent from running on wrong host
block_exec_by_host()
{
echo "==> Validating execution host"

# for this prototype, only allow this work to be done on the Control Server
if [ $ADMIN_CHECKED -ne $TRUE ]; then
  echo "      (I) Nothing to be done for this host."
  echo "          Returning control to main executing thread."
  exit 0;
fi

echo "      (I) Execution host is valid.  Program will continue."
return 0;
}


###


#
copy_pre_script()   
{
echo "==> Starting to copy the pre script"

cp "$AMX_MISC_DIR/AMX_Create_Comp_Msmt.sh" "$TWH_TOPDIR/tools/bin"  

echo "      (I) Done copying the pre script"
return 0;
}

copy_amx_rollup()   
{
echo "==> Starting to copy the amx rollup script"

cp "$AMX_MISC_DIR/AMX_Rollup.sh" "$TWH_TOPDIR/tools/bin"  

echo "      (I) Done copying the amx rollup script"
return 0;
}


#
set_db2_params()   
{
echo "==> Starting to set DB2 parameters"


# is the CDW and mart local?
if [ "$CDW_CHECKED" = "$TRUE" ]; then
  echo "    Local CDW..."

  err_txt=`$DB2EXEC update db cfg for "$TWH_CDW_DB" using APP_CTL_HEAP_SZ 512 2>&1 `
  if [ $? -ne 0 ]; then
    echo "==> (F) Failed to set APP_CTL_HEAP_SZ for $TWH_CDW_DB database"
    echo "        Error is:"
    echo "        $err_txt"
    echo "        Exiting..."
    exit 255
  fi

  tmp_sql_drop_tssys_bp="drop tablespace tssystemp8k;
  drop bufferpool buf8k;"
  tmp_sql_bp="create bufferpool buf8k size 500 pagesize 8 K;"

  # Create a 8K page size bufferpool
  # Drop the sys temp tablespace then the 8K page size bufferpool
  echo "      (I) Drop sys temp tablespace and bufferpool"
  echo "$tmp_sql_drop_tssys_bp" > "$TMPDIR/$tmp_sql_file"
  gr_build_exec_script "$TWH_CDW_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CDW_TYPE $CONN_TYPE_CONNECT;
  gr_exec_sql_script "$TWH_CDW_DB" $FALSE;
  rm -f "$TMPDIR/$tmp_sql_file"

  # Create it
  echo "      (I) Create bufferpool"
  echo "$tmp_sql_bp" > "$TMPDIR/$tmp_sql_file"
  gr_build_exec_script "$TWH_CDW_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CDW_TYPE $CONN_TYPE_CONNECT;
  gr_exec_sql_script "$TWH_CDW_DB" $TRUE;
  rm -f "$TMPDIR/$tmp_sql_file"


  # Bounce DB2 
  echo "==> Stopping DB2"
  err_txt=`$DB2CMD db2stop force 2>&1 `
  if [ $? -ne 0 ]; then
    blah=`echo $err_txt | grep -i $sql_db_not_started `
    if [ $? -eq 0 ]; then
      :;                  # If db not started that is OK
    else
      echo "==> (F) Failed to stop DB2."
      echo "        Error is:"
      echo "        $err_txt"
      echo "        Exiting..."
      exit 255
    fi
  fi


  # Start DB2
  echo "==> Starting DB2"
  err_txt=`$DB2CMD db2start 2>&1 `

  # Note: ignore errors from db2start
  # Test a connection
  echo "      (I) Testing the DB connection"
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CDW_DB" user "$COPT_CDW_DB2USER" using "$COPT_CDW_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CDW_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi

  # Have to do this again in case db2bp thread was forced
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CDW_DB" user "$COPT_CDW_DB2USER" using "$COPT_CDW_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CDW_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi

  # create system temp tablespace that uses 8K page size bufferpool
  tmp_sql_tssys="create system temporary tablespace tssystemp8k pagesize 8 K managed by system using ('tssystemp8k') bufferpool buf8k;"

  # Create it
  echo "      (I) Create system temp tablespace"
  echo "$tmp_sql_tssys" > "$TMPDIR/$tmp_sql_file"
  gr_build_exec_script "$TWH_CDW_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CDW_TYPE $CONN_TYPE_CONNECT;
  gr_exec_sql_script "$TWH_CDW_DB" $TRUE;
  rm -f "$TMPDIR/$tmp_sql_file"

# We have a remote CDW
else
  echo "    Remote CDW..."

  # Prep vars
  sql_drop_users="disconnect all;
detach;"

  sql_set_inst_parm="update db cfg for "$TWH_CDW_DB" using APP_CTL_HEAP_SZ 512;
disconnect all;
detach;"

  sql_drop_db_parms="drop tablespace tssystemp8k;
drop bufferpool buf8k;"

  sql_set_db_parms="create bufferpool buf8k size 500 pagesize 8 K;
create system temporary tablespace tssystemp8k pagesize 8 K managed by system using ('tssystemp8k') bufferpool buf8k;"


  # Build and run script to drop users
  echo "      (I) Dropping applications users from CDW"
  echo "$sql_drop_users" > "$TMPDIR/$tmp_sql_file"
  gr_build_exec_script "$TWH_CDW_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CDW_TYPE $CONN_TYPE_ATTACH;
  gr_exec_sql_script "$TWH_CDW_DB" $TRUE;
  rm -f "$TMPDIR/$tmp_sql_file"

  # drop users is asynchronous - pause
  sleep 10

  # Build and run script set instance parm
  echo "      (I) Setting instance parameters"
  echo "$sql_set_inst_parm" > "$TMPDIR/$tmp_sql_file"
  gr_build_exec_script "$TWH_CDW_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CDW_TYPE $CONN_TYPE_ATTACH;
  gr_exec_sql_script "$TWH_CDW_DB" $TRUE;
  rm -f "$TMPDIR/$tmp_sql_file"


  # Build and run script to drop users
  echo "      (I) Dropping DB parameters"
  echo "$sql_drop_db_parms" > "$TMPDIR/$tmp_sql_file"
  gr_build_exec_script "$TWH_CDW_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CDW_TYPE $CONN_TYPE_CONNECT;
  gr_exec_sql_script "$TWH_CDW_DB" $FALSE;
  rm -f "$TMPDIR/$tmp_sql_file"


  # Build and run script to set parms
  echo "      (I) Setting DB parms (appl heap and bufferpool)"
  echo "$sql_set_DB_parms" > "$TMPDIR/$tmp_sql_file"
  gr_build_exec_script "$TWH_CDW_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CDW_TYPE $CONN_TYPE_CONNECT;
  gr_exec_sql_script "$TWH_CDW_DB" $TRUE;
  rm -f "$TMPDIR/$tmp_sql_file"


  # Test a connection
  echo "      (I) Testing the DB connection"
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CDW_DB" user "$COPT_CDW_DB2USER" using "$COPT_CDW_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CDW_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi

  # Have to do this again in case db2bp thread was forced
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CDW_DB" user "$COPT_CDW_DB2USER" using "$COPT_CDW_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CDW_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi


  # Build and run script to drop users (Again)
  echo "      (I) Dropping applications users from CDW - again"
  echo "$sql_drop_users" > "$TMPDIR/$tmp_sql_file"
  gr_build_exec_script "$TWH_CDW_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CDW_TYPE $CONN_TYPE_ATTACH;
  gr_exec_sql_script "$TWH_CDW_DB" $TRUE;
  rm -f "$TMPDIR/$tmp_sql_file"
fi

echo "      (I) Done setting DB parameters"
return 0;
}


############
### Main ###
############

echo "==> Processing main WPack routines"
echo ""

  set_amx_program_vars;
  block_exec_by_host;
  copy_pre_script;
  copy_amx_rollup;
  set_db2_params;    

echo ""
echo "      (I) Done processing main WPack routines"           

#####################################
## Stop adding application code #####
#####################################
exec_core_after;		# DO NOT MOVE OR REMOVE!


echo ""
echo "==> Completed executing application after script"
exit 0
