#!/bin/sh
############################################################################
#
#  Licensed Materials - Property of IBM
#  Product ID = 5724-C04
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#  File Information: Common/src/tedw_app/amx/pkg/v511/misc/amx_after.sh, tmnt_etl, tmnt_5.1.1, DM020906B
#  Revision: 1.5
#  Date: 9/3/02 10:25:49
############################################################################

############################################################################
# Command Line Args:
#	1 = the path and name of the TWH Application config file
#	2 = Application working directory or install base directory
#		$TWH_TOPDIR/apps/ava_code_for_app/vapp_version (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this script called amx_after.sh.log
#
# Required Env Vars:
#       None.
#
# Return Codes:
#	0 = Success
#	255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#       6 - TWH Core tools and application components must be
#	      successfully installed
#
# What is accomplished:
#  * Copy the AMX_Create_Comp_Msmt.sh into $TWH_TOPDIR/tools/bin
#
# Note - Caution needs to be taken for NT paths that have a space.  This
#        is a limitation that requires double quoting around all 
#	   variables that contain a path.  Testing should be done to ensure
#	   this script runs with a space in any of the paths that are used.
#########################################################################
#


###
echo "        ** Before Script Log **          "
echo ""
echo "****************************************"
echo "* Application Before Script Start point *"
echo "****************************************"
echo ""

# Pulls in the generic shared routines

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Execute startup driver for beforescript
. "$TWH_TOPDIR"/install/bin/twh_core_startup_after.sh
exec_startup_driver;

#####################################################
######## Add application code below here ONLY #######
#####################################################

#
set_amx_program_vars()
{
tmp_sql_file="amx_tmp_sql.sql"        # name of the temporary sql file
return 0;
}


###


# Update the End dates to Infinite In TWG.Relnrul for the ABA, GWP, GWI and GWA WEPs
update_end_date()
{

  # Test a connection
  echo "      (I) Testing the DB connection"
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CDW_DB" user "$COPT_CDW_DB2USER" using "$COPT_CDW_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CDW_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi

  echo "==> Updating the End dates to Infinite In TWG.Relnrul for the ABA, GWP, GWI and GWA WEPs"
  
  sql_update_end_date="update twg.relnrul set relnrul_end_dttm='9999-01-01-00.00.00.000000' where substr(comptyp_target_cd,1,3) in ('ABA', 'GWP', 'GWI', 'GWA');"
  echo "connect to $TWH_CDW_DB user $COPT_CDW_DB2USER using $COPT_CDW_DB2PASS;" > "$TMPDIR/$tmp_sql_file";
  echo "$sql_update_end_date" >> "$TMPDIR/$tmp_sql_file"
  $DB2EXEC -xtf "$TMPDIR/$tmp_sql_file" |sed -e '1,8d' -e 's/ //g' 

  ret=$?
  if [ $ret -gt 2 ] ; then
	  echo "      (F) Unable to find the update the TWG.RelnRul table"
          echo "          for the the ABA, GWP, GWI and GWA WEPs in the TWH_CDW database:"
          echo "          Exiting..."
    exit 255
  fi

  
  rm -f "$TMPDIR/$tmp_sql_file"

echo "      (I) TWG.RelnRul table updated for the ABA, GWP, GWI and GWA WEPs. Program will continue."
return 0;
}





############
### Main ###
############

echo "==> Processing main WPack routines"
echo ""

  set_amx_program_vars;
  update_end_date;

echo ""
echo "      (I) Done processing main WPack routines"           


echo ""
echo "==> Completed executing application before script"
exit 0
