-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amy/fixpack2/cdw/ddl/amy_cdw_schema.sql, tmnt_etl, tmnt_5.1.1_FP04
-- #  Revision: 1.2
-- #  Date: 12/18/02 12:55:49
-- ############################################################################

--#iftag fixpack_400

----------------------------------------
-- CREATE NEW HELPER TABLES AND VIEWS --
----------------------------------------

--
-- //////// AMY_FOWNER
--
CREATE VIEW AMY.V_FOWNER AS
SELECT 
 C1.COMP_ID                    AS FILE_ID,
 C1.COMP_STRT_DTTM             AS FILE_STRT_DTTM,
 C1.COMP_NM                    AS FILE_NAME,
 VALUE(CA1.COMPATTR_VAL,'N/A') AS FILE_OWNER
FROM
 TWG.CUR_COMP C1 left outer join TWG.CUR_COMPATTR CA1
 ON C1.COMP_ID = CA1.COMP_ID
WHERE
 C1.COMPTYP_CD = 'AMY_FILE' AND
 (CA1.ATTRTYP_CD = 'AMY_FOWNER' OR CA1.ATTRTYP_CD IS NULL)
GROUP BY C1.COMP_ID, C1.COMP_STRT_DTTM , C1.COMP_NM, CA1.COMPATTR_VAL
;

--
-- //////// AMY_FMODE
--
CREATE VIEW AMY.V_FMODE AS
SELECT 
 C1.COMP_ID                    AS FILE_ID,
 C1.COMP_STRT_DTTM             AS FILE_STRT_DTTM,	
 C1.COMP_NM                    AS FILE_NAME,
 VALUE(CA1.COMPATTR_VAL,'N/A') AS FILE_PERMISSIONS
FROM
 TWG.CUR_COMP C1 left outer join TWG.CUR_COMPATTR CA1
 ON C1.COMP_ID = CA1.COMP_ID
WHERE
 C1.COMPTYP_CD = 'AMY_FILE' AND
 (CA1.ATTRTYP_CD = 'AMY_FMODE' OR CA1.ATTRTYP_CD IS NULL)
GROUP BY C1.COMP_ID, C1.COMP_STRT_DTTM , C1.COMP_NM, CA1.COMPATTR_VAL
;

--
-- //////// AMY_FGROUP
--
CREATE VIEW AMY.V_FGROUP AS
SELECT 
 C1.COMP_ID                    AS FILE_ID,
 C1.COMP_STRT_DTTM             AS FILE_STRT_DTTM,	
 C1.COMP_NM                    AS FILE_NAME,
 VALUE(CA1.COMPATTR_VAL,'N/A') AS FILE_GROUP
FROM
 TWG.CUR_COMP C1 left outer join TWG.CUR_COMPATTR CA1
 ON C1.COMP_ID = CA1.COMP_ID
WHERE
 C1.COMPTYP_CD = 'AMY_FILE' AND
 (CA1.ATTRTYP_CD = 'AMY_FGROUP' OR CA1.ATTRTYP_CD IS NULL)
GROUP BY C1.COMP_ID, C1.COMP_STRT_DTTM , C1.COMP_NM, CA1.COMPATTR_VAL
;
--
-- //////// AMY.V_FILE
--
CREATE VIEW AMY.V_FILE AS
SELECT
  V1.FILE_ID          AS FILE_ID,
  V1.FILE_STRT_DTTM   AS FILE_STRT_DTTM,
  V1.FILE_NAME        AS FILE_NAME,
  V1.FILE_OWNER       AS FILE_OWNER,
  V2.FILE_PERMISSIONS AS FILE_PERMISSIONS,
  V3.FILE_GROUP       AS FILE_GROUP
FROM 
  AMY.V_FOWNER V1, AMY.V_FMODE V2, AMY.V_FGROUP V3
WHERE
  V1.FILE_ID = V2.FILE_ID AND
  V1.FILE_ID = V3.FILE_ID
;

--
-- Here we create some support views used to perform the hostname decomposition into
-- network_domain, network_subdomain and eventually second level network_subdomain
-- with a different approach in order to avoid the usage of the Com_Ds field, not 
-- always updated by the ETL1 process...
--
drop view AMY.hostname_v1;
create view AMY.hostname_v1 as 
select
  c1.Comp_ID as host_id, 
  c1.Comp_Nm as hostname,
  LOCATE('.',c1.Comp_Nm) + 1 as name_b_beg,
  LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm) + 1) + 1 as name_c_beg,
  LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm) + 1) + 1) + 1 as name_d_beg,
  LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm) + 1) + 1) + 1) + 1 as name_e_beg
from
  TWG.Comp c1,  TWG.Comp c2, TWG.CompReln cr  
where 
  c1.comp_id = cr.comp_source_id and
  c2.comp_id = cr.comp_target_id and
  c1.comptyp_cd in ('AMY_HOST','IP_HOST')
group by
  c1.Comp_ID, c1.Comp_Nm
;
--
-- the AMY.hostname_v2 must be recreated because it refers the AMY.hostname_v1
-- droppped and recreated view and it is in an inoperative status...
--
create view AMY.hostname_v2 as
select
  host_id,
  hostname,
  name_b_beg,
  name_c_beg,
  name_d_beg,
  name_e_beg,
  case when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg > 1) then 5
       when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg = 1) then 4
       when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg = 1 ) then 3
       when (name_b_beg > 1 and name_c_beg = 1 ) then 2
       when (name_b_beg = 1 ) then 1
  end  as name_parts
from
  AMY.hostname_v1
;
--
-- the AMY.hostname_decomp must be recreated because it refers the AMY.hostname_v2
-- recreated view and it is in an inoperative status...
--
create view AMY.hostname_decomp as
select
  host_id,      
  hostname,   
  CASE 
    when name_parts = 5 then substr(hostname,name_d_beg)        
    when name_parts = 4 then substr(hostname,name_c_beg)        
    when name_parts = 3 then substr(hostname,name_b_beg)        
    else 'no value'   
  END as network_domain,   
  CASE 
    when name_parts = 5 then substr(hostname,name_c_beg)        
    when name_parts = 4 then substr(hostname,name_b_beg)        
    else 'no value'   
  END as network_subdomain,   
  CASE 
    when name_parts = 5 then substr(hostname,name_b_beg)        
    else 'no value'   
  END as network_subdomain2,
  CASE 
    when hostname is null THEN null        
    when name_b_beg > 1 THEN SUBSTR(hostname, 1, name_b_beg - 2)        
    else hostname         
  END as short_hostname
from  AMY.hostname_v2
;

--#endtag fixpack_400
