-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amy/fixpack2/cdw/dml/amy_cdw_data.sql, tmnt_etl, tmnt_5.1.1_FP04
-- #  Revision: 1.3
-- #  Date: 3/17/03 18:42:02
-- ############################################################################

--#iftag fixpack_400

---------------------------------------------
---------------------------------------------
-- ////// Fixes for the AMY metadatas ///////
---------------------------------------------
---------------------------------------------

--
-- fix the name of the metric 'PagesFaultsSec' collected by the TMW_MemoryModel
--
UPDATE TWG.MsmtTyp
SET MsmtTyp_Nm = 'PagesFaultsSec'
WHERE MsmtTyp_Nm = 'PageFaultsSec' and
not exists ( select 1 from TWG.MsmtTyp where MsmtTyp_Nm = 'PagesFaultsSec');

UPDATE AMY.STAGE_D_ITM_METRIC
SET MET_NAME = 'PagesFaultsSec'
WHERE MET_NAME = 'PageFaultsSec'
;

-- IY38862: fix the data format of the metric 'TotalAvail' collected by the DMXMemory RM

UPDATE TWG.MsmtTyp                                                      
SET MUNIT_CD = 'B'                                                      
WHERE MSMTTYP_NM = 'TotalAvail'                                         
AND MSRC_CD = 'AMY'                                                       
;

UPDATE AMY.STAGE_D_ITM_METRIC
SET MET_UNITS = 'B'
WHERE MET_NAME = 'TotalAvail'
AND MSRC_NM = 'ITM for Operating Systems'
;

-- The File resource is mapped to the AMY_FILE component using the AMX.Resource_Transl
-- translation table, but the logging key used by the DMXFile resource model is not
-- unique between the different logging contexts: it is "fileName" for the "File Checksum"
-- context and "pathname" for the "File Times" context.
--
-- For this reason the key attribute "fileName" is absorbed by "pathname" key attribute
-- using the AMX_Inst_Key_Convert conversion table and thus, the only attributes of the
-- File resource that are mapped to TEDW component attributes are:
--
-- MSRC_CD ITM_ATTR_PROPERTY   ATTRTYP_CD        
-- ------- ------------------- ----------------- 
-- AMY     File.group          AMY_FGROUP        
-- AMY     File.owner          AMY_FOWNER        
-- AMY     File.mode           AMY_FMODE         

DELETE FROM TWG.AttrRul
WHERE ATTRTYP_CD = 'AMY_FPATHNM';

DELETE FROM TWG.AttrTyp
WHERE ATTRTYP_CD = 'AMY_FPATHNM';

-------------------------------------------------------------------
-------------------------------------------------------------------
-- ////// Static data for ITM for Operating System FixPack2 ///////
-------------------------------------------------------------------
-------------------------------------------------------------------

--
-- NOTE: as a general rule, we use a where-not-exist clause to avoid 
-- duplicate entries and subsequent unique constraint violation...
--

--------------
-- TWG.CompTyp
--------------
--
-- Component Type: 
-- Defines the type of components or sub-components being monitored.
-- NOTE: CompTyp_Cd is the primary key
--
declare global temporary table AMY_CompTyp (
  CompTyp_Cd           CHAR(17)     NOT NULL,
  CompTyp_Parent_Cd    CHAR(17),
  CompTyp_Nm           VARCHAR(120) NOT NULL,
  CompTyp_Strt_DtTm    TIMESTAMP    NOT NULL,
  CompTyp_End_DtTm     TIMESTAMP    NOT NULL
) 
with replace on commit preserve rows not logged
;

--insert into session.AMY_CompTyp values ('',  null , '', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into TWG.CompTyp (
  CompTyp_Cd, CompTyp_Parent_Cd,
  CompTyp_Nm, CompTyp_Strt_DtTm,
  CompTyp_End_DtTm )
select * from session.AMY_CompTyp s
where not exists (
  select 1 from
  TWG.Cur_CompTyp t 
  where
  t.CompTyp_Cd = s.CompTyp_Cd )
;

--------------
-- TWG.MsmtTyp
--------------
--
-- Measurement Type (this is unique for each application):
-- Defines a type of mesurement that may be collected for a component, based
-- on its Component Type.
-- 
-- NOTE: records added to TWG.MsmtTyp are enumerated by an ascending sequence 
-- on the field MsmtTyp_ID, which is also the primary key of the table; there is 
-- also a unique index on the MsmtTyp_Nm field
--
declare global temporary table AMY_MsmtTyp (
  MUnit_Cd             CHAR(6)      NOT NULL,
  MSrc_Cd              CHAR(6)      NOT NULL,
  MsmtTyp_Nm           VARCHAR(120) NOT NULL,
  MsmtTyp_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged
;

--insert into session.AMY_MsmtTyp values ('', 'AMY', '', '');

insert into TWG.MsmtTyp (
  MUnit_Cd, MSrc_Cd,
  MsmtTyp_Nm, MsmtTyp_Ds )
select * from session.AMY_MsmtTyp s
where not exists (
  select 1 from
  TWG.MsmtTyp t 
  where
  t.MsmtTyp_Nm = s.MsmtTyp_Nm )
;

--------------
-- TWG.MsmtRul
--------------
--
-- Measurement Rule: (this is unique for each application)
-- Defines which types of measurements are appropriate for which types of components.
--
declare global temporary table AMY_MsmtRul (
  CompTyp_Cd   char(17) not null,
  MsmtTyp_ID   integer not null
)
with replace on commit preserve rows not logged
;

--insert into session.AMY_MsmtRul
--select 'AMY_XXX', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
--'');

insert into TWG.MsmtRul (
  CompTyp_Cd, MsmtTyp_ID )
select * from session.AMY_MsmtRul s
where not exists ( 
  select 1 from 
  TWG.MsmtRul t 
  where 
  t.MsmtTyp_ID = s.MsmtTyp_ID and
  t.CompTyp_Cd = s.CompTyp_Cd 
);


--------------
-- TWG.AttrTyp 
--------------
--
-- Attribute Types:
-- Defines the type of caractheristics or properties that may be captured about a component.
--
-- /////// NOTE: AttrTyp_Cd is the primary key of the table
-- /////// RULE: When the key is composed of multiple names all of them appear in the attribute table. 
-- ///////       When the key is composed of one unique name, it does not appear in the attribute table. 
-- ///////       When the key is an integer, the name of the component appears in the attribute table.
--
declare global temporary table AMY_AttrTyp (
  AttrTyp_Cd    CHAR(17) NOT NULL,
  AttrTyp_Nm    VARCHAR(120) NOT NULL
) 
with replace on commit preserve rows not logged
;

--insert into session.AMY_AttrTyp values ('', '');

insert into TWG.AttrTyp (
  AttrTyp_Cd, AttrTyp_Nm )
select * from session.AMY_AttrTyp s
where not exists ( 
  select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd = s.AttrTyp_Cd )
;

--------------
-- TWG.MGrpMbr
--------------
--
-- Measurement Group Member:
-- Defines a type of measurement within a particular grouping (Measurement Group);
-- a Measurement Type may be a member of several Measurement Groups.
--
declare global temporary table AMY_MGrpMbr (
  MGrp_Cd      char(6) not null,
  MGrpTyp_Cd   char(6) not null,
  MsmtTyp_ID   integer not null
)
with replace on commit preserve rows not logged
;

-- ////////////////////////////////////////////////////////////////////////////////////
-- MIN_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////// UNIX_Linux Resource Models
insert into session.AMY_MGrpMbr
select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in ( 
'modificationTime', 'changeTime', 'checksum');

-- ////////////////////////////////////////////////////////////////////////////////////
-- MAX_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////// UNIX_Linux Resource Models
insert into session.AMY_MGrpMbr
select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in ( 
'modificationTime', 'changeTime', 'checksum');

-- ////////////////////////////////////////////////////////////////////////////////////
-- AVG_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////// UNIX_Linux Resource Models
insert into session.AMY_MGrpMbr
select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in ( 
'modificationTime', 'changeTime', 'checksum');

-- ////////////////////////////////////////////////////////////////////////////////////
-- TOT_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// UNIX_Linux/Solaris Resource Models
insert into session.AMY_MGrpMbr
select 'TOT_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in ( 
'' );

---------------------------------------------------------------------------------------
-- Categorizations specific to "ITM Monitoring Collection for Operating Systems" (ITM)
---------------------------------------------------------------------------------------

-- ////////////////////////////////////////////////////////////////////////////////////
-- CPU_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////////////////////////////////////////////////////////////////////////////////////
-- MEM_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////////////////////////////////////////////////////////////////////////////////////
-- NIC_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////////////////////////////////////////////////////////////////////////////////////
-- HD_E ///////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////////////////////////////////////////////////////////////////////////////////////
-- FS_E ///////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////////////////////////////////////////////////////////////////////////////////////
-- SEC_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////////////////////////////////////////////////////////////////////////////////////
-- PRN_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

insert into TWG.MGrpMbr (
  MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID )
select * from session.AMY_MGrpMbr s
where not exists ( 
  select 1 from
  TWG.MGrpMbr t
  where
  t.MGrpTyp_Cd = s.MGrpTyp_Cd and
  t.MGrp_Cd = s.MGrp_Cd and
  t.MsmtTyp_ID = s.MsmtTyp_ID )
;  

--------------
-- TWG.RelnRul 
--------------
--
-- Relationship Rule:
-- Defines which types of components may participate in which type of relationships.
--

declare global temporary table AMY_RelnRul (
  CompTyp_Source_Cd    CHAR(17)  NOT NULL,
  CompTyp_Target_Cd    CHAR(17)  NOT NULL,
  RelnTyp_Cd           CHAR(6)   NOT NULL,
  RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
  RelnRul_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

-- ////////////////////////////////////////////////////
-- //////// Windows NT/2000/XP Resource Models ////////
-- ////////////////////////////////////////////////////

insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PDISK',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_LDISK',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PROCESS',  'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_MEMORY',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_REDIR',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_NETSEG',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_SERVER',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
--the windows specific AMY_NIC component is mapped to the generic AMY_NETWORK component
--insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_NIC',      'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_SERVICE',  'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PORT',     'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PRNQUEUE', 'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
--the windows specific AMY_PROCESSOR component is mapped to the generic AMY_CPU component
--insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PROCESSOR','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
--the windows specific AMY_SYSTEM component is mapped to the generic AMY_CPU component
--insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_SYSTEM',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_TCPIP',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_IP',       'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

-- ////////////////////////////////////////////
-- //////// UNIX_Linux Resource Models ////////
-- ////////////////////////////////////////////

insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_CPU',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_FILE',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_FS',     'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_NETWORK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_NFS',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_RPC',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_USER',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

-- ////////////////////////////////////////////
-- ////////// OS400 Resource Models ///////////
-- ////////////////////////////////////////////

insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400DISK', 'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400IFCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400DBCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400ICPU', 'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400BCPU', 'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400ASP',  'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400SPOOL','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into TWG.RelnRul (
  CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
  RelnRul_Strt_DtTm, RelnRul_End_DtTm )
select * from session.AMY_RelnRul s
where not exists ( 
  select 1 from
  TWG.RelnRul t
  where
  t.CompTyp_Source_Cd = s.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = s.CompTyp_Target_Cd and
  t.RelnTyp_Cd = s.RelnTyp_Cd )
; 

--------------
-- TWG.AttrRul
--------------
--
-- Attribute Rule:
-- Defines which type of attributes may be tracked for which types of components.
-- NOTE: the fields (CompTyp_Cd, AttrTyp_Cd) constitute the primary key of the table
--
declare global temporary table AMY_AttrRul (
  CompTyp_Cd           CHAR(17) NOT NULL,
  AttrTyp_Cd           CHAR(17) NOT NULL,
  AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
  AttrRul_End_DtTm     TIMESTAMP NOT NULL,
  AttrRul_Dom_Ind      CHAR NOT NULL
)
with replace on commit preserve rows not logged
;   

--insert into session.AMY_AttrRul values ('','',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');

insert into TWG.AttrRul (
  CompTyp_Cd, AttrTyp_Cd, AttrRul_Strt_DtTm, 
  AttrRul_End_DtTm, AttrRul_Dom_Ind )
select * from session.AMY_AttrRul s
where not exists ( 
  select 1 from
  TWG.AttrRul t 
  where
  t.CompTyp_Cd = s.CompTyp_Cd and
  t.AttrTyp_Cd = s.AttrTyp_Cd )
;

--------------
-- TWG.AttrDom 
--------------
--
-- Attribute Domain:
-- One insatance of a set of valid values for a Component Attribute Type; 
-- it is only used when the set of valid values is predefined.
--
-- NOTE: records added to TWG.AttrDom are enumerated by an ascending sequence 
-- on the field AttrDom_ID
--
declare global temporary table AMY_AttrDom (
  CompTyp_Cd           CHAR(17) NOT NULL,
  AttrTyp_Cd           CHAR(17) NOT NULL,
  AttrDom_Strt_DtTm    TIMESTAMP NOT NULL,
  AttrDom_End_DtTm     TIMESTAMP NOT NULL,
  AttrDom_Val          VARCHAR(254) NOT NULL,
  AttrDom_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged
;

-- NOTE: becasue the TEDW FixPack2 doesn't solve the problem of the missing trigger on the AttrDom_ID
-- field, we cannot define the domain over which the parametric resource models take values

--insert into session.AMY_AttrDom values ('AMY_PORT', 'AMY_PORTSTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','CLOSED','Port is closed');
--insert into session.AMY_AttrDom values ('AMY_PORT', 'AMY_PORTSTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','CLOSING','Port is closing');
--insert into session.AMY_AttrDom values ('AMY_PORT', 'AMY_PORTSTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','CLOSE_WAIT','Port is waiting to close');
--insert into session.AMY_AttrDom values ('AMY_PORT', 'AMY_PORTSTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','FIN_WAIT','FIN_WAIT for the port');
--insert into session.AMY_AttrDom values ('AMY_PORT', 'AMY_PORTSTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','FIN_WAIT2','FIN_WAIT2 for the port');
--insert into session.AMY_AttrDom values ('AMY_PORT', 'AMY_PORTSTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','TIME_WAIT','TIME_WAIT for the port');
--insert into session.AMY_AttrDom values ('AMY_PORT', 'AMY_PORTSTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','ESTABLISHED','Connection established on port');
--insert into session.AMY_AttrDom values ('AMY_PORT', 'AMY_PORTSTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','LISTENING','Port is listening');
--insert into session.AMY_AttrDom values ('AMY_PORT', 'AMY_PORTSTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','???','Unknown port state');

--insert into session.AMY_AttrDom values ('AMY_SERVICE', 'AMY_SERVICESTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','Stopped','Service is stopped');
--insert into session.AMY_AttrDom values ('AMY_SERVICE', 'AMY_SERVICESTATE', current timestamp - current timezone, '9999-01-01-00.00.00.000000','Started','Service is Started');
--insert into session.AMY_AttrDom values ('AMY_SERVICE', 'AMY_SERVICESTATUS', current timestamp - current timezone, '9999-01-01-00.00.00.000000','OK','Service is OK');
--insert into session.AMY_AttrDom values ('AMY_SERVICE', 'AMY_SERVICESTATUS', current timestamp - current timezone, '9999-01-01-00.00.00.000000','ERROR','Service is in Error');

insert into TWG.AttrDom (
  CompTyp_Cd, AttrTyp_Cd,
  AttrDom_Strt_DtTm, AttrDom_End_DtTm,
  AttrDom_Val, AttrDom_Ds )
select * from session.AMY_AttrDom s
where not exists ( 
  select 1 from
  TWG.AttrDom t 
  where
  t.CompTyp_Cd = s.CompTyp_Cd and
  t.AttrTyp_Cd = s.AttrTyp_Cd and
  t.AttrDom_Val = s.AttrDom_Val ) 
;

---------------------------------------------
---------------------------------------------
-- /////////// Translation tables ///////////
---------------------------------------------
---------------------------------------------

----------------------
-- AMX.Resource_Transl
----------------------

--
-- //////// Resource (Resources) ---> Component Type (CompTyp)
-- //////// NOTE: there is a unique index on CompTyp_Cd
--
declare global temporary table AMX_Resource_Transl (
  Resource		 varchar(50) not null,
  CompTyp_Cd	 varchar(17) not null
)
with replace on commit preserve rows not logged
;

-- NOTE: it is not possible to define a n:1 relationship, because
-- the AMX.Resource_Transl defines CompTyp_Cd as PRIMARY KEY; we 
-- need a different CompTyp_Cd for each distinct ITM Resource...

--insert into session.AMX_Resource_Transl values ('', '');

insert into AMX.Resource_Transl
select * from session.AMX_Resource_Transl s
where not exists ( 
  select 1 from
  AMX.Resource_Transl t
  where
  t.CompTyp_Cd = s.CompTyp_Cd )
; 

-------------------------
-- AMX.Categories_Convert
-------------------------

--
-- NOTE: this table is used by the Generic ETL1 parsing process in order
-- to convert the multiple categories used for Operating System Resource
-- Models into a generic OperatingSystem category, because the ETL1 doesn't
-- support an n:1 mapping for the category
--
declare global temporary table AMX_Categories_Convert (
  Category_Convert	varchar(64) not null,
  Category     		varchar(64) not null,
  Description  		varchar(128)
)
with replace on commit preserve rows not logged
;

--insert into session.AMX_Categories_Convert values ('OperatingSystem','','');

insert into AMX.Categories_Convert
select * from session.AMX_Categories_Convert s
where not exists ( 
  select 1 from 
  AMX.Categories_Convert t
  where
  t.Category_Convert = s.Category_Convert and
  t.Category = s.Category )
; 

-----------------------
-- AMX.Inst_key_Convert
-----------------------

-- This table is used to support any product that
-- may have created multiples ITM keys for the same component type 
-- such as ITM Operating System Resource models
-- we convert all the Key_Typ to a unique Key_Typ_Convert 

declare global temporary table AMX_Inst_Key_Convert (
  Key_Typ_Convert	varchar(255) not null,
  Key_Typ		      varchar(255) not null,
  Description  		varchar(128)
)
with replace on commit preserve rows not logged
;

--insert into session.AMX_Inst_Key_Convert values ('','','');

insert into AMX.Inst_Key_Convert
select * from session.AMX_Inst_Key_Convert s
where not exists ( 
  select 1 from 
  AMX.Inst_Key_Convert t
  where 
  t.Key_Typ_Convert = s.Key_Typ_Convert and
  t.Key_Typ = s.Key_Typ )
;

------------------------
-- AMX.Resources_Convert
------------------------

-- This table is used to support any product that
-- needs to convert multiple resource names to one 
-- unique name, which is used to map a TEDW CompTyp
-- by the AMX.Resource_Transl table...

declare global temporary table AMX_Resources_Convert (
  Resource_Convert varchar(128) not null,
  Resource         varchar(128) not null,
  Description      varchar(128)
)
with replace on commit preserve rows not logged
;

--insert into session.AMX_Resources_Convert values ('','','');

insert into AMX.Resources_Convert
select * from session.AMX_Resources_Convert s
where not exists ( 
  select 1 from 
  AMX.Resources_Convert t
  where 
  t.Resource_Convert = s.Resource_Convert and
  t.Resource = s.Resource )
;

---------------------
-- AMX.CompTyp_Transl
---------------------

--
-- //////// Logged Key Property (Instances.Instance_Key) ---> Component Type (CompTyp)
--
-- //////// NOTE: there is a unique index on (MSrc_Cd, CompTyp_Cd)
-- //////// RULE: Here we define a lookup table for conversion between ITM 
-- ////////       key properties and TEDW Components keys.
-- ////////       - MSrc_Cd is the AVA code for the producs;
-- ////////       - ITM_Key_Property is the list of the properties in the "key" parameter
-- ////////         of in DefineLogInst, where the properties are primary keys; if there
-- ////////         are multiple properties they are separated by a semicolon; this value
-- ////////         is always in the form Resource.Property and defines the ITM side of 
-- ////////         the mapping;
-- ////////       - CompTyp_Cd is the component type code, i.e. the code of the TEDW CompTyp
-- ////////         which maps the ITM Resources;
-- ////////       - Comp_Format_Nm contains the ITM properties that constitute the display 
-- ////////         name.
--
declare global temporary table AMX_CompTyp_Transl (
  MSrc_Cd           char(3) not null,
  ITM_Key_Property  varchar(600) not null,
  CompTyp_Cd        varchar(17) not null,
  Comp_Format_Nm    varchar(120) not null
)
with replace on commit preserve rows not logged
;

--insert into session.AMX_CompTyp_Transl values ('AMY', '', '', '');

insert into AMX.Comptyp_Transl
select * from session.AMX_Comptyp_Transl s
where not exists ( 
  select 1 from 
  AMX.CompTyp_Transl t
  where
  t.MSrc_Cd = s.MSrc_Cd and
  t.CompTyp_Cd  = s.CompTyp_Cd )
; 

---------------------
-- AMX.AttrTyp_Transl
---------------------

--
-- /////// Logged Non-Key Property (Instances.instance_key) --> Attribute Type (AttrType)
--
-- /////// NOTE: There is a unique index on (MSrc_Cd, ITM_Attr_Property, AttrTyp_Cd)
-- /////// RULE: When the key is composed of multiple names all of them appear in the attribute table. 
-- ///////       When the key is composed of one unique name, it does not appear in the attribute table. 
-- ///////       When the key is an integer, the name of the component appears in the attribute table.
--
declare global temporary table AMX_AttrTyp_Transl (
  MSrc_Cd           char(3) not null,
  AMY_Attr_Property varchar(120) not null,
  AttrTyp_Cd        varchar(17) not null
)
with replace on commit preserve rows not logged
;

--insert into session.AMX_AttrTyp_Transl values ('AMY','', '');

insert into AMX.Attrtyp_Transl
select * from session.AMX_Attrtyp_Transl s
where not exists ( 
  select 1 from
  AMX.Attrtyp_Transl t
  where
  t.MSrc_Cd = s.MSrc_Cd and
  t.AttrTyp_Cd  = s.AttrTyp_Cd )
; 

---------------------
-- AMX.RelnRul_Transl
---------------------

--
-- //////// Component Relationship (RelnRul)
--
declare global temporary table AMX_RelnRul_Transl (
  CompTyp_Source_Cd	  varchar(17) not null,
  CompTyp_Target_Cd	  varchar(17) not null,
  RelnTyp_Cd          char(6) not null,
  RelnRul_Strt_DtTm   timestamp not null,
  RelnRul_End_DtTm    timestamp not null
)
with replace on commit preserve rows not logged
;

-- NOTE: this is used only for PROXY components

insert into AMX.RelnRul_Transl
select * from session.AMX_RelnRul_Transl s
where not exists (
  select 1 from 
  AMX.RelnRul_Transl t
  where
  t.CompTyp_Source_Cd = s.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = s.CompTyp_Target_Cd and
  t.RelnTyp_Cd = s.RelnTyp_Cd )
;

----------------------------------------------------------
----------------------------------------------------------
-- ////// Static data for the Extract Control Table //////
----------------------------------------------------------
----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE Extract_Control (
  ExtCtl_Source         VARCHAR(120) NOT NULL,
  ExtCtl_Target         VARCHAR(120) NOT NULL,
  ExtCtl_From_RawSeq    CHAR(10) FOR BIT DATA,
  ExtCtl_To_RawSeq      CHAR(10) FOR BIT DATA,
  ExtCtl_From_IntSeq    BIGINT NOT NULL,
  ExtCtl_To_IntSeq      BIGINT NOT NULL,
  ExtCtl_From_DtTm      TIMESTAMP,
  ExtCtl_To_DtTm        TIMESTAMP
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

---------------------------------------------
-- from TWG.Msmt to the Hourly Fact Tables --
---------------------------------------------

INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_CPU_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_FILE_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_FS_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_LDISK_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_PDISK_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_PROCESS_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_MEMORY_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_NETWORK_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_PRINTER_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'AMY.STAGE_F_SECURITY_HOUR', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');

---------------------------------------------------------------
-- from staging tables in CDW to the metric dimension tables --
---------------------------------------------------------------

INSERT INTO session.Extract_Control VALUES ('AMY.STAGE_D_ITM_METRIC', 'AMY.D_CPU_METRIC', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('AMY.STAGE_D_ITM_METRIC', 'AMY.D_FS_METRIC', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('AMY.STAGE_D_ITM_METRIC', 'AMY.D_IO_METRIC', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('AMY.STAGE_D_ITM_METRIC', 'AMY.D_MEM_METRIC', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('AMY.STAGE_D_ITM_METRIC', 'AMY.D_NET_METRIC', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('AMY.STAGE_D_ITM_METRIC', 'AMY.D_PRN_METRIC', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('AMY.STAGE_D_ITM_METRIC', 'AMY.D_SEC_METRIC', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');

-------------------------------------------------------
-- from CDW tables to the component dimension tables --
-------------------------------------------------------

INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_HOST_IP', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_CPU', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_FILE', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_FS', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_LDISK', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_PDISK', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_PROCESS', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_MEMORY', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_NETWORK', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_PRINTER', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'AMY.D_SECURITY', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');

INSERT INTO TWG.Extract_Control
SELECT 
  m.ExtCtl_Source,
  m.ExtCtl_Target,
  m.ExtCtl_From_RawSeq,
  m.ExtCtl_To_RawSeq,
  m.ExtCtl_From_IntSeq,
  m.ExtCtl_To_IntSeq,
  m.ExtCtl_From_DtTm,
  m.ExtCtl_To_DtTm  
FROM 
  session.Extract_Control m
WHERE NOT EXISTS ( 
  SELECT 1 FROM
    TWG.Extract_Control t
  WHERE
    t.ExtCtl_Source = m.ExtCtl_Source AND
    t.ExtCtl_Target = m.ExtCtl_Target
);


----------------------------------------------------------
----------------------------------------------------------
-- /////// Static data for Metric Dimension tables ///////
----------------------------------------------------------
----------------------------------------------------------

--
-- Insert static data into the staging table used to build the Metric Dimension 
-- Table, which stores a single piece of descriptive information used to identify 
-- fact table records...
--

declare global temporary table temp_min_exists (
 MsmtTyp_ID   integer,
 Min_Exists   char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_min_exists
select
 mb.MsmtTyp_ID as MsmtTyp_ID,
 'Y'           as Avg_Exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt
where
 mb.MGrpTyp_Cd = 'GROUP' and
 mb.MGrp_Cd='MIN_E' and
 mb.MsmtTyp_ID = mt.MsmtTyp_ID and
 mt.MSrc_Cd = 'AMY'
;

select count(*) from session.temp_min_exists;

declare global temporary table temp_max_exists (
 MsmtTyp_ID	  integer,
 Max_Exists   char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_max_exists
select
 mb.MsmtTyp_ID as MsmtTyp_ID,
 'Y'           as Avg_Exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt
where
 mb.MGrpTyp_Cd = 'GROUP' and
 mb.MGrp_Cd='MAX_E' and
 mb.MsmtTyp_ID = mt.MsmtTyp_ID and
 mt.MSrc_Cd = 'AMY'
;

select count(*) from session.temp_max_exists;

declare global temporary table temp_avg_exists (
 MsmtTyp_ID	  integer,
 Avg_Exists   char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_avg_exists
select
 mb.MsmtTyp_ID as MsmtTyp_ID,
 'Y'           as Avg_Exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt
where
 mb.MGrpTyp_Cd = 'GROUP' and
 mb.MGrp_Cd='AVG_E' and
 mb.MsmtTyp_ID = mt.MsmtTyp_ID and
 mt.MSrc_Cd = 'AMY'
;

select count(*) from session.temp_avg_exists;

declare global temporary table temp_tot_exists (
 MsmtTyp_ID	  integer,
 Tot_Exists   char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_tot_exists
select
 mb.MsmtTyp_ID as MsmtTyp_ID,
 'Y'           as Avg_Exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt
where
 mb.MGrpTyp_Cd = 'GROUP' and
 mb.MGrp_Cd='TOT_E' and
 mb.MsmtTyp_ID = mt.MsmtTyp_ID and
 mt.MSrc_Cd = 'AMY'
;

select count(*) from session.temp_tot_exists;

declare global temporary table temp_category (
 MsmtTyp_ID	  integer,
 Category     varchar(120)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_category
select
 mb.MsmtTyp_ID as MsmtTyp_ID,
 mg.MGrp_Nm    as Category
from
 TWG.MgrpMbr mb,
 TWG.Mgrp mg
where
 mb.mgrptyp_cd = 'ITM' and
 mb.mgrp_cd in ('CPU_E','MEM_E','NIC_E','HD_E','FS_E','SEC_E','PRN_E') and
 mb.mgrp_cd = mg.mgrp_cd
;

select count(*) from session.temp_category;

DROP TABLE AMY.STAGE_D_ITM_METRIC;

CREATE TABLE AMY.STAGE_D_ITM_METRIC (
  metric_id            INTEGER       NOT NULL,
  insert_dttm          TIMESTAMP     NOT NULL,
  met_name             VARCHAR(254)  NOT NULL,
  met_desc             VARCHAR(254),
  met_units            VARCHAR(254)  NOT NULL,
  met_category         VARCHAR(254)  NOT NULL,
  min_exists           CHARACTER     NOT NULL,
  max_exists           CHARACTER     NOT NULL,
  avg_exists           CHARACTER     NOT NULL,
  total_exists         CHARACTER     NOT NULL,
  msrc_nm              VARCHAR(254),
    PRIMARY KEY (metric_id)
);

insert into AMY.STAGE_D_ITM_METRIC (
  metric_id, insert_dttm, 
  met_name, met_desc, met_units, met_category,
  min_exists, max_exists, avg_exists, total_exists,
  msrc_nm )
select
  mt1.msmttyp_id              as metric_id,
  current timestamp - 
  current timezone            as insert_dttm,
  mt1.msmttyp_nm              as met_name,
  mt1.msmttyp_ds              as met_desc,
  mt1.munit_cd                as met_units,
  value(cat.category,'')      as met_category,
  value(min.min_exists,'N')   as min_exists,
  value(max.max_exists,'N')   as max_exists,
  value(avg.avg_exists,'N')   as avg_exists,
  value(tot.tot_exists,'N')   as total_exists,
  'ITM for Operating Systems' as msrc_nm
from
  TWG.msmttyp mt1 left outer join session.temp_min_exists min
  on mt1.msmttyp_id = min.msmttyp_id,
  TWG.msmttyp mt2 left outer join session.temp_max_exists max
  on mt2.msmttyp_id = max.msmttyp_id,
  TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
  on mt3.msmttyp_id = avg.msmttyp_id,
  TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
  on mt4.msmttyp_id = tot.msmttyp_id,
  TWG.msmttyp mt5 left outer join session.temp_category cat
  on mt5.msmttyp_id = cat.msmttyp_id,
  TWG.MsmtRul mr
where
  mt1.msmttyp_id = mr.msmttyp_id and 
  mr.comptyp_cd in (select distinct CompTyp_Cd from TWG.CompTyp where substr(CompTyp_Cd,1,3) = 'AMY') and
  mt1.MSrc_Cd = 'AMY' and
  mt1.msmttyp_id = mt2.msmttyp_id and
  mt1.msmttyp_id = mt3.msmttyp_id and
  mt1.msmttyp_id = mt4.msmttyp_id and
  mt1.msmttyp_id = mt5.msmttyp_id
group by
  mt1.msmttyp_id, mt1.msmttyp_nm, mt1.msmttyp_ds, mt1.munit_cd, 
  min_exists, avg_exists, tot_exists, max_exists, cat.category
;

--#endtag fixpack_400
