-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amy/fixpack2/etl/sql/AMY_m05_s010_metric.db2, tmnt_etl, tmnt_5.1.1, 511ITM04C
-- #  Revision: 1.1
-- #  Date: 11/13/02 10:07:42
-- ############################################################################

------------------------------------------------------------------------------------------------
-- fill the AMY.D_CPU_METRIC metric dimension table with CPU and Process related metrics
------------------------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// at: TWH_CDW
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(METRIC_ID) 
                        FROM AMY.STAGE_D_ITM_METRIC 
                       WHERE UPPER(MET_CATEGORY) = 'CPU' )
WHERE 
  EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EXTCTL_TARGET = 'AMY.D_CPU_METRIC' AND
  EXISTS (SELECT METRIC_ID
            FROM AMY.STAGE_D_ITM_METRIC
           WHERE UPPER(MET_CATEGORY) = 'CPU')   
;
--
-- //////// copy the CPU and Process related metrics from the AMY.STAGE_D_ITM_METRIC
-- //////// staging table to the AMY.D_CPU_METRIC metric dimension table...
-- //////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.D_CPU_METRIC
SELECT
  S.METRIC_ID,
  S.MET_NAME,
  S.MET_DESC,
  S.MET_UNITS,
  S.MET_CATEGORY,
  S.MSRC_NM,
  S.MIN_EXISTS,
  S.MAX_EXISTS,
  S.AVG_EXISTS,
  S.TOTAL_EXISTS
FROM 
  AMY.STAGE_D_ITM_METRIC S,
  TWG.EXTRACT_CONTROL EC
WHERE 
  UPPER(S.MET_CATEGORY) = 'CPU' AND
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_CPU_METRIC' AND
  S.METRIC_ID > EC.EXTCTL_FROM_INTSEQ AND
  S.METRIC_ID <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
  EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
  CURRENT TIMESTAMP - 
  CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
  TWG.EXTRACT_CONTROL EC
WHERE
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_CPU_METRIC'
;

------------------------------------------------------------------------------------------------
-- fill the AMY.D_FS_METRIC metric dimension table with File and Files System related metrics
------------------------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// at: TWH_CDW
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(METRIC_ID) 
                        FROM AMY.STAGE_D_ITM_METRIC 
                       WHERE UPPER(MET_CATEGORY) = 'FILE SYSTEM' )
WHERE 
  EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EXTCTL_TARGET = 'AMY.D_FS_METRIC' AND
  EXISTS (SELECT METRIC_ID
            FROM AMY.STAGE_D_ITM_METRIC
           WHERE UPPER(MET_CATEGORY) = 'FILE SYSTEM')   
;
--
-- //////// copy the File and File System related metrics from the AMY.STAGE_D_ITM_METRIC
-- //////// staging table to the AMY.D_FS_METRIC metric dimension table...
-- //////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.D_FS_METRIC
SELECT
  S.METRIC_ID,
  S.MET_NAME,
  S.MET_DESC,
  S.MET_UNITS,
  S.MET_CATEGORY,
  S.MSRC_NM,
  S.MIN_EXISTS,
  S.MAX_EXISTS,
  S.AVG_EXISTS,
  S.TOTAL_EXISTS
FROM 
  AMY.STAGE_D_ITM_METRIC S,
  TWG.EXTRACT_CONTROL EC
WHERE 
  UPPER(S.MET_CATEGORY) = 'FILE SYSTEM' AND
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_FS_METRIC' AND
  S.METRIC_ID > EC.EXTCTL_FROM_INTSEQ AND
  S.METRIC_ID <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
  EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
  CURRENT TIMESTAMP - 
  CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
  TWG.EXTRACT_CONTROL EC
WHERE
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_FS_METRIC'
;

------------------------------------------------------------------------------------------------
-- fill the AMY.D_IO_METRIC metric dimension table with Disk I/O related metrics
------------------------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// at: TWH_CDW
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(METRIC_ID) 
                        FROM AMY.STAGE_D_ITM_METRIC 
                       WHERE UPPER(MET_CATEGORY) = 'I/O' )
WHERE 
  EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EXTCTL_TARGET = 'AMY.D_IO_METRIC' AND
  EXISTS (SELECT METRIC_ID
            FROM AMY.STAGE_D_ITM_METRIC
           WHERE UPPER(MET_CATEGORY) = 'I/O')   
;
--
-- //////// copy the Disk I/O related metrics from the AMY.STAGE_D_ITM_METRIC
-- //////// staging table to the AMY.D_IO_METRIC metric dimension table...
-- //////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.D_IO_METRIC
SELECT
  S.METRIC_ID,
  S.MET_NAME,
  S.MET_DESC,
  S.MET_UNITS,
  S.MET_CATEGORY,
  S.MSRC_NM,
  S.MIN_EXISTS,
  S.MAX_EXISTS,
  S.AVG_EXISTS,
  S.TOTAL_EXISTS
FROM 
  AMY.STAGE_D_ITM_METRIC S,
  TWG.EXTRACT_CONTROL EC
WHERE 
  UPPER(S.MET_CATEGORY) = 'I/O' AND
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_IO_METRIC' AND
  S.METRIC_ID > EC.EXTCTL_FROM_INTSEQ AND
  S.METRIC_ID <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
  EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
  CURRENT TIMESTAMP - 
  CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
  TWG.EXTRACT_CONTROL EC
WHERE
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_IO_METRIC'
;

------------------------------------------------------------------------------------------------
-- fill the AMY.D_MEM_METRIC metric dimension table with Memory related metrics
------------------------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// at: TWH_CDW
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(METRIC_ID) 
                        FROM AMY.STAGE_D_ITM_METRIC 
                       WHERE UPPER(MET_CATEGORY) = 'MEMORY' )
WHERE 
  EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EXTCTL_TARGET = 'AMY.D_MEM_METRIC' AND
  EXISTS (SELECT METRIC_ID
            FROM AMY.STAGE_D_ITM_METRIC
           WHERE UPPER(MET_CATEGORY) = 'MEMORY')   
;
--
-- //////// copy the Memory related metrics from the AMY.STAGE_D_ITM_METRIC
-- //////// staging table to the AMY.D_MEM_METRIC metric dimension table...
-- //////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.D_MEM_METRIC
SELECT
  S.METRIC_ID,
  S.MET_NAME,
  S.MET_DESC,
  S.MET_UNITS,
  S.MET_CATEGORY,
  S.MSRC_NM,
  S.MIN_EXISTS,
  S.MAX_EXISTS,
  S.AVG_EXISTS,
  S.TOTAL_EXISTS
FROM 
  AMY.STAGE_D_ITM_METRIC S,
  TWG.EXTRACT_CONTROL EC
WHERE 
  UPPER(S.MET_CATEGORY) = 'MEMORY' AND
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_MEM_METRIC' AND
  S.METRIC_ID > EC.EXTCTL_FROM_INTSEQ AND
  S.METRIC_ID <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
  EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
  CURRENT TIMESTAMP - 
  CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
  TWG.EXTRACT_CONTROL EC
WHERE
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_MEM_METRIC'
;

------------------------------------------------------------------------------------------------
-- fill the AMY.D_NET_METRIC metric dimension table with Network related metrics
------------------------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// at: TWH_CDW
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(METRIC_ID) 
                        FROM AMY.STAGE_D_ITM_METRIC 
                       WHERE UPPER(MET_CATEGORY) = 'NETWORK INTERFACE' )
WHERE 
  EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EXTCTL_TARGET = 'AMY.D_NET_METRIC' AND
  EXISTS (SELECT METRIC_ID
            FROM AMY.STAGE_D_ITM_METRIC
           WHERE UPPER(MET_CATEGORY) = 'NETWORK INTERFACE')   
;
--
-- //////// copy the Networkrelated metrics from the AMY.STAGE_D_ITM_METRIC
-- //////// staging table to the AMY.D_NET_METRIC metric dimension table...
-- //////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.D_NET_METRIC
SELECT
  S.METRIC_ID,
  S.MET_NAME,
  S.MET_DESC,
  S.MET_UNITS,
  S.MET_CATEGORY,
  S.MSRC_NM,
  S.MIN_EXISTS,
  S.MAX_EXISTS,
  S.AVG_EXISTS,
  S.TOTAL_EXISTS
FROM 
  AMY.STAGE_D_ITM_METRIC S,
  TWG.EXTRACT_CONTROL EC
WHERE 
  UPPER(S.MET_CATEGORY) = 'NETWORK INTERFACE' AND
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_NET_METRIC' AND
  S.METRIC_ID > EC.EXTCTL_FROM_INTSEQ AND
  S.METRIC_ID <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
  EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
  CURRENT TIMESTAMP - 
  CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
  TWG.EXTRACT_CONTROL EC
WHERE
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_NET_METRIC'
;

------------------------------------------------------------------------------------------------
-- fill the AMY.D_PRN_METRIC metric dimension table with Printer related metrics
------------------------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// at: TWH_CDW
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(METRIC_ID) 
                        FROM AMY.STAGE_D_ITM_METRIC 
                       WHERE UPPER(MET_CATEGORY) = 'PRINTER' )
WHERE 
  EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EXTCTL_TARGET = 'AMY.D_PRN_METRIC' AND
  EXISTS (SELECT METRIC_ID
            FROM AMY.STAGE_D_ITM_METRIC
           WHERE UPPER(MET_CATEGORY) = 'PRINTER')   
;
--
-- //////// copy the Printer related metrics from the AMY.STAGE_D_ITM_METRIC
-- //////// staging table to the AMY.D_PRN_METRIC metric dimension table...
-- //////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.D_PRN_METRIC
SELECT
  S.METRIC_ID,
  S.MET_NAME,
  S.MET_DESC,
  S.MET_UNITS,
  S.MET_CATEGORY,
  S.MSRC_NM,
  S.MIN_EXISTS,
  S.MAX_EXISTS,
  S.AVG_EXISTS,
  S.TOTAL_EXISTS
FROM 
  AMY.STAGE_D_ITM_METRIC S,
  TWG.EXTRACT_CONTROL EC
WHERE 
  UPPER(S.MET_CATEGORY) = 'PRINTER' AND
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_PRN_METRIC' AND
  S.METRIC_ID > EC.EXTCTL_FROM_INTSEQ AND
  S.METRIC_ID <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
  EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
  CURRENT TIMESTAMP - 
  CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
  TWG.EXTRACT_CONTROL EC
WHERE
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_PRN_METRIC'
;

------------------------------------------------------------------------------------------------
-- fill the AMY.D_SEC_METRIC metric dimension table with Printer related metrics
------------------------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// at: TWH_CDW
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(METRIC_ID) 
                        FROM AMY.STAGE_D_ITM_METRIC 
                       WHERE UPPER(MET_CATEGORY) = 'SECURITY' )
WHERE 
  EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EXTCTL_TARGET = 'AMY.D_SEC_METRIC' AND
  EXISTS (SELECT METRIC_ID
            FROM AMY.STAGE_D_ITM_METRIC
           WHERE UPPER(MET_CATEGORY) = 'SECURITY')   
;
--
-- //////// copy the Security related metrics from the AMY.STAGE_D_ITM_METRIC
-- //////// staging table to the AMY.D_SEC_METRIC metric dimension table...
-- //////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.D_SEC_METRIC
SELECT
  S.METRIC_ID,
  S.MET_NAME,
  S.MET_DESC,
  S.MET_UNITS,
  S.MET_CATEGORY,
  S.MSRC_NM,
  S.MIN_EXISTS,
  S.MAX_EXISTS,
  S.AVG_EXISTS,
  S.TOTAL_EXISTS
FROM 
  AMY.STAGE_D_ITM_METRIC S,
  TWG.EXTRACT_CONTROL EC
WHERE 
  UPPER(S.MET_CATEGORY) = 'SECURITY' AND
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_SEC_METRIC' AND
  S.METRIC_ID > EC.EXTCTL_FROM_INTSEQ AND
  S.METRIC_ID <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
  EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
  CURRENT TIMESTAMP - 
  CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
  TWG.EXTRACT_CONTROL EC
WHERE
  EC.EXTCTL_SOURCE = 'AMY.STAGE_D_ITM_METRIC' AND
  EC.EXTCTL_TARGET = 'AMY.D_SEC_METRIC'
;

