-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amy/fixpack2/etl/sql/AMY_m05_s020_dimension.db2, tmnt_etl, tmnt_5.1.1, 511ITM04C
-- #  Revision: 1.3
-- #  Date: 12/19/02 13:32:06
-- ############################################################################

-------------------------------------------------------------------------------
-- fill the AMY.D_HOST_IP dimension table with the AMY_HOSTs and/or IP_HOSTs  
-- and with their attributes, if any...
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET
 EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                       FROM TWG.CUR_COMP
                      WHERE COMPTYP_CD IN ('IP_HOST', 'AMY_HOST', 'IP_INTERFACE'))
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_HOST_IP' AND
 EXISTS (SELECT MAX(COMP_ID) 
           FROM TWG.CUR_COMP
          WHERE COMPTYP_CD IN ('IP_HOST', 'AMY_HOST', 'IP_INTERFACE')
);

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_HOST_IP
SELECT DISTINCT
  C.COMP_ID             AS HOST_ID,
  C.COMP_STRT_DTTM      AS HOST_START_DTTM,
  C.COMP_END_DTTM       AS HOST_END_DTTM,
  C.COMP_NM             AS HOSTNAME,
  H.NETWORK_DOMAIN      AS NETWORK_DOMAIN,    
  H.NETWORK_SUBDOMAIN   AS NETWORK_SUBDOMAIN,    
  H.NETWORK_SUBDOMAIN2  AS NETWORK_SUBDOMAIN2,    
  H.SHORT_HOSTNAME      AS SHORT_HOSTNAME,
  'N/A'                 AS LAST_IP_ADDRESS,
  CU.CUST_NM            AS CUSTOMER_NAME,
  CE.CENTR_NM           AS CENTER_NAME 
FROM 
  TWG.CUR_COMP C, AMY.HOSTNAME_DECOMP H, 
  TWG.CUST CU, TWG.CENTR CE, TWG.EXTRACT_CONTROL EC
WHERE 
  C.COMP_ID = H.HOST_ID AND
  C.COMPTYP_CD IN ('AMY_HOST', 'IP_HOST') AND
  CU.CUST_ID = C.CUST_ID AND
  CE.CENTR_CD = C.CENTR_CD  AND
  EC.EXTCTL_SOURCE = 'TWG.COMP' AND
  EC.EXTCTL_TARGET = 'AMY.D_HOST_IP' AND
  C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
  C.COMP_ID <= EC.EXTCTL_TO_INTSEQ
UNION
SELECT DISTINCT
  C1.COMP_ID            AS HOST_ID,
  C1.COMP_STRT_DTTM     AS HOST_START_DTTM,
  C1.COMP_END_DTTM      AS HOST_END_DTTM,
  C1.COMP_NM            AS HOSTNAME,
  'N/A'                 AS NETWORK_DOMAIN,    
  'N/A'                 AS NETWORK_SUBDOMAIN,    
  'N/A'                 AS NETWORK_SUBDOMAIN2,    
  'N/A'	            AS SHORT_HOSTNAME,
  'N/A'                 AS LAST_IP_ADDRESS,
  CU.CUST_NM            AS CUSTOMER_NAME,
  CE.CENTR_NM           AS CENTER_NAME 
FROM 
  TWG.CUR_COMP C1, TWG.CUR_COMP C2,
  TWG.COMPRELN CR, TWG.CUST CU, TWG.CENTR CE, TWG.EXTRACT_CONTROL EC
WHERE
  C1.COMP_ID = CR.COMP_SOURCE_ID AND
  C2.COMP_ID = CR.COMP_TARGET_ID AND
  C2.COMPTYP_CD LIKE 'AMY%' AND
  C1.COMPTYP_CD IN ('IP_INTERFACE') AND
  EC.EXTCTL_SOURCE = 'TWG.COMP' AND
  EC.EXTCTL_TARGET = 'AMY.D_HOST_IP' AND
  C1.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
  C1.COMP_ID <= EC.EXTCTL_TO_INTSEQ
;

--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_HOST_IP'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_CPU dimension table with the monitored CPUs...
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET
 EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                       FROM TWG.CUR_COMP
                      WHERE COMPTYP_CD = 'AMY_CPU')
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_CPU' AND
 EXISTS (SELECT MAX(COMP_ID) 
           FROM TWG.CUR_COMP
          WHERE COMPTYP_CD = 'AMY_CPU'
);

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_CPU
SELECT 
  C.COMP_ID   AS CPU_ID,
  C.COMP_NM   AS CPU_NM
FROM 
  TWG.COMP C, TWG.EXTRACT_CONTROL EC
WHERE
  C.COMPTYP_CD = 'AMY_CPU' AND
  EC.EXTCTL_SOURCE = 'TWG.COMP' AND
  EC.EXTCTL_TARGET = 'AMY.D_CPU' AND
  C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
  C.COMP_ID <= EC.EXTCTL_TO_INTSEQ
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_CPU'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_FILE dimension table with the monitored files and their 
-- attributes...
-------------------------------------------------------------------------------
--
-- NOTE: if there are some files without attributes in the TWG.COMPATTR table and 
-- the following simple query only returns a subset of the monitored files (only 
-- the files with attributes...), for this reason we implement a more safe approach  
-- when filling the AMY.D_FILE tabele, leveraging on some views used to substitute 
-- the missing attributes with a 'N/A' string...
--
-- INSERT INTO AMY.D_FILE
-- SELECT 
--  C.COMP_ID        AS FILE_ID,
--  C.COMP_NM        AS FILE_NAME,
--  CA1.COMPATTR_VAL AS FILE_OWNER,
--  CA2.COMPATTR_VAL AS FILE_PERMISSIONS,
--  CA3.COMPATTR_VAL AS FILE_GROUP
-- FROM
--  TWG.COMP C, TWG.COMPRELN CR, TWG.COMPATTR CA1, 
--  TWG.COMPATTR CA2, TWG.COMPATTR CA3
-- WHERE
--  C.COMP_ID = CR.COMP_TARGET_ID AND
--  C.COMPTYP_CD IN ('AMY_FILE') AND
--  C.COMP_ID = CA1.COMP_ID AND
--  CA1.ATTRTYP_CD = 'AMY_FOWNER' AND
--  C.COMP_ID = CA2.COMP_ID AND
--  CA2.ATTRTYP_CD = 'AMY_FMODE' AND
--  C.COMP_ID = CA3.COMP_ID AND
--  CA3.ATTRTYP_CD = 'AMY_FGROUP'
-- ;

--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(FILE_ID) 
                        FROM AMY.V_FILE )
WHERE 
  EXTCTL_SOURCE = 'TWG.COMP' AND
  EXTCTL_TARGET = 'AMY.D_FILE' AND
  (SELECT COUNT(*) FROM AMY.V_FILE) > 0
;

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_FILE
SELECT
  VF.FILE_ID          AS FILE_ID,
  VF.FILE_NAME        AS FILE_NAME,
  VF.FILE_OWNER       AS FILE_OWNER,
  VF.FILE_PERMISSIONS AS FILE_PERMISSIONS,
  VF.FILE_GROUP       AS FILE_GROUP
FROM 
  AMY.V_FILE VF, TWG.EXTRACT_CONTROL EC
WHERE
  EC.EXTCTL_SOURCE = 'TWG.COMP' AND
  EC.EXTCTL_TARGET = 'AMY.D_FILE' AND
  VF.FILE_ID > EC.EXTCTL_FROM_INTSEQ AND
  VF.FILE_ID <= EC.EXTCTL_TO_INTSEQ 
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_FILE'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_FS dimension table with the monitored file systems...
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                        FROM TWG.CUR_COMP
                       WHERE COMPTYP_CD = 'AMY_FS')
WHERE 
  EXTCTL_SOURCE = 'TWG.COMP' AND
  EXTCTL_TARGET = 'AMY.D_FS' AND
  EXISTS (SELECT MAX(COMP_ID) 
            FROM TWG.CUR_COMP
           WHERE COMPTYP_CD = 'AMY_FS'
);  

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_FS
SELECT 
  C.COMP_ID  AS FS_ID,
  C.COMP_NM  AS FS_MOUNTPOINT
FROM
  TWG.COMP C, TWG.EXTRACT_CONTROL EC
WHERE
  C.COMPTYP_CD = 'AMY_FS' AND
  EC.EXTCTL_SOURCE = 'TWG.COMP' AND
  EC.EXTCTL_TARGET = 'AMY.D_FS' AND
  C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
  C.COMP_ID <= EC.EXTCTL_TO_INTSEQ 	
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_FS'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_LDISK dimension table with the monitored Logical Disks
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                        FROM TWG.CUR_COMP
                       WHERE COMPTYP_CD = 'AMY_LDISK')
WHERE 
  EXTCTL_SOURCE = 'TWG.COMP' AND
  EXTCTL_TARGET = 'AMY.D_LDISK' AND
  EXISTS (SELECT MAX(COMP_ID) 
            FROM TWG.CUR_COMP
           WHERE COMPTYP_CD = 'AMY_LDISK'
);  

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_LDISK
SELECT 
  C.COMP_ID  AS LDISK_ID,
  C.COMP_NM  AS LDISK_NM
FROM
  TWG.COMP C, TWG.EXTRACT_CONTROL EC
WHERE
  C.COMPTYP_CD = 'AMY_LDISK' AND
  EC.EXTCTL_SOURCE = 'TWG.COMP' AND
  EC.EXTCTL_TARGET = 'AMY.D_LDISK' AND
  C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
  C.COMP_ID <= EC.EXTCTL_TO_INTSEQ 	
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_LDISK'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_PDISK dimension table with the monitored Phisical Disks...
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                        FROM TWG.CUR_COMP
                       WHERE COMPTYP_CD = 'AMY_PDISK')
WHERE 
  EXTCTL_SOURCE = 'TWG.COMP' AND
  EXTCTL_TARGET = 'AMY.D_PDISK' AND
  EXISTS (SELECT MAX(COMP_ID) 
            FROM TWG.CUR_COMP
           WHERE COMPTYP_CD = 'AMY_PDISK'
);  

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_PDISK
SELECT 
  C.COMP_ID  AS PDISK_ID,
  C.COMP_NM  AS PDISK_NM
FROM
  TWG.COMP C, TWG.EXTRACT_CONTROL EC
WHERE
  C.COMPTYP_CD = 'AMY_PDISK' AND
  EC.EXTCTL_SOURCE = 'TWG.COMP' AND
  EC.EXTCTL_TARGET = 'AMY.D_PDISK' AND
  C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
  C.COMP_ID <= EC.EXTCTL_TO_INTSEQ 	
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_PDISK'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_PROCESS dimension table with the monitored Processes...
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                        FROM TWG.CUR_COMP
                       WHERE COMPTYP_CD = 'AMY_PROCESS')
WHERE 
  EXTCTL_SOURCE = 'TWG.COMP' AND
  EXTCTL_TARGET = 'AMY.D_PROCESS' AND
  EXISTS (SELECT MAX(COMP_ID) 
            FROM TWG.CUR_COMP
           WHERE COMPTYP_CD = 'AMY_PROCESS'
);  

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_PROCESS
SELECT 
 C.COMP_ID   AS PROCESS_ID,
 C.COMP_NM   AS PROC_NM,
 CASE 
   WHEN LOCATE('.', COMPATTR_VAL) != 0 
     THEN SUBSTR(COMPATTR_VAL,1,LOCATE('.', COMPATTR_VAL)-1)
   WHEN LOCATE(',', COMPATTR_VAL) != 0 
     THEN SUBSTR(COMPATTR_VAL,1,LOCATE(',', COMPATTR_VAL)-1)
 END AS PROC_ID
FROM
 TWG.COMP C, TWG.COMPRELN CR, TWG.COMPATTR CA1, TWG.EXTRACT_CONTROL EC
WHERE
 C.COMP_ID = CR.COMP_TARGET_ID AND
 C.COMPTYP_CD = 'AMY_PROCESS' AND
 C.COMP_ID = CA1.COMP_ID AND
 CA1.ATTRTYP_CD = 'AMY_PROCID' AND
 EC.EXTCTL_SOURCE = 'TWG.COMP' AND
 EC.EXTCTL_TARGET = 'AMY.D_PROCESS' AND
 C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
 C.COMP_ID <= EC.EXTCTL_TO_INTSEQ 	
;

--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_PROCESS'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_MEMORY dimension table with the monitored Memory...
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                        FROM TWG.CUR_COMP
                       WHERE COMPTYP_CD = 'AMY_MEMORY')
WHERE 
  EXTCTL_SOURCE = 'TWG.COMP' AND
  EXTCTL_TARGET = 'AMY.D_MEMORY' AND
  EXISTS (SELECT MAX(COMP_ID) 
            FROM TWG.CUR_COMP
           WHERE COMPTYP_CD = 'AMY_MEMORY'
);  

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_MEMORY
SELECT 
 C.COMP_ID   AS MEMORY_ID,
 C.COMP_NM   AS MEMORY_NM
FROM
 TWG.COMP C, TWG.COMPRELN CR, TWG.EXTRACT_CONTROL EC
WHERE
 C.COMP_ID = CR.COMP_TARGET_ID AND
 C.COMPTYP_CD = 'AMY_MEMORY' AND
 EC.EXTCTL_SOURCE = 'TWG.COMP' AND
 EC.EXTCTL_TARGET = 'AMY.D_MEMORY' AND
 C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
 C.COMP_ID <= EC.EXTCTL_TO_INTSEQ 	
;

--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_MEMORY'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_NETWORK dimension table with the monitored Network Interface...
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                        FROM TWG.CUR_COMP
                       WHERE COMPTYP_CD IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP'))
WHERE 
  EXTCTL_SOURCE = 'TWG.COMP' AND
  EXTCTL_TARGET = 'AMY.D_NETWORK' AND
  EXISTS (SELECT MAX(COMP_ID) 
            FROM TWG.CUR_COMP
           WHERE COMPTYP_CD IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP')
);  

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_NETWORK
SELECT 
 C.COMP_ID   AS NET_ID,
 CASE
   WHEN (C.COMP_NM = '' OR C.COMP_NM IS NULL)
     THEN 'N/A'
     ELSE C.COMP_NM
 END AS NET_NM
FROM
 TWG.COMP C, TWG.COMPRELN CR, TWG.EXTRACT_CONTROL EC
WHERE
 C.COMP_ID = CR.COMP_TARGET_ID AND
 C.COMPTYP_CD IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP') AND
 EC.EXTCTL_SOURCE = 'TWG.COMP' AND
 EC.EXTCTL_TARGET = 'AMY.D_NETWORK' AND
 C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
 C.COMP_ID <= EC.EXTCTL_TO_INTSEQ 	
;

--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_NETWORK'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_PRINTER dimension table with the monitored Printers...
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                        FROM TWG.CUR_COMP
                       WHERE COMPTYP_CD = 'AMY_PRNQUEUE')
WHERE 
  EXTCTL_SOURCE = 'TWG.COMP' AND
  EXTCTL_TARGET = 'AMY.D_PRINTER' AND
  EXISTS (SELECT MAX(COMP_ID) 
            FROM TWG.CUR_COMP
           WHERE COMPTYP_CD = 'AMY_PRNQUEUE'
);  

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_PRINTER
SELECT 
 C.COMP_ID   AS PRN_ID,
 C.COMP_NM   AS PRN_NM
FROM
 TWG.COMP C, TWG.COMPRELN CR, TWG.EXTRACT_CONTROL EC
WHERE
 C.COMP_ID = CR.COMP_TARGET_ID AND
 C.COMPTYP_CD IN ('AMY_PRNQUEUE') AND
 EC.EXTCTL_SOURCE = 'TWG.COMP' AND
 EC.EXTCTL_TARGET = 'AMY.D_PRINTER' AND
 C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
 C.COMP_ID <= EC.EXTCTL_TO_INTSEQ 	
;

--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_PRINTER'
; 

-------------------------------------------------------------------------------
-- fill the AMY.D_SECURITY dimension table with the security related metrics...
-------------------------------------------------------------------------------
--
-- //////// set the high value for the data to be extracted...
-- //////// from: TWH_CDW to: TWH_MART
--
UPDATE TWG.EXTRACT_CONTROL SET 
  EXTCTL_TO_INTSEQ = (SELECT MAX(COMP_ID) 
                        FROM TWG.CUR_COMP
                       WHERE COMPTYP_CD IN ('AMY_USER', 'AMY_SERVER'))
WHERE 
  EXTCTL_SOURCE = 'TWG.COMP' AND
  EXTCTL_TARGET = 'AMY.D_SECURITY' AND
  EXISTS (SELECT MAX(COMP_ID) 
            FROM TWG.CUR_COMP
           WHERE COMPTYP_CD IN ('AMY_USER', 'AMY_SERVER')
);  

--#INSERT_INTO_TARGET
INSERT INTO AMY.D_SECURITY
SELECT 
 C.COMP_ID   AS SEC_ID,
 C.COMP_NM   AS SEC_NM
FROM
 TWG.COMP C, TWG.COMPRELN CR, TWG.EXTRACT_CONTROL EC
WHERE
 C.COMP_ID = CR.COMP_TARGET_ID AND
 C.COMPTYP_CD IN ('AMY_USER', 'AMY_SERVER') AND
 EC.EXTCTL_SOURCE = 'TWG.COMP' AND
 EC.EXTCTL_TARGET = 'AMY.D_SECURITY' AND
 C.COMP_ID > EC.EXTCTL_FROM_INTSEQ AND
 C.COMP_ID <= EC.EXTCTL_TO_INTSEQ 	
;

--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE      AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET      AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - 
 CURRENT TIMEZONE      AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ   AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ   AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM   AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM     AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EXTCTL_SOURCE = 'TWG.COMP' AND
 EXTCTL_TARGET = 'AMY.D_SECURITY'
; 

