-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amy/fixpack2/etl/sql/AMY_m05_s030_prune_fact.db2, tmnt_etl, tmnt_5.1.1, 511ITM04C
-- #  Revision: 1.1
-- #  Date: 11/13/02 10:07:44
-- ############################################################################

-- ////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\ DATA MART PRUNING SECTION /\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////
-- /// Prunes obsolete data from all fact tables based on the value in the ////
-- //////////// PMartC_Duration column for the associated table. //////////////
-- ////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/ CPU FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////
--
-- //////// Log the pruning of the hourly fact table AMY.F_CPU_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_CPU_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_CPU_HOUR'),
  ( select count(*) from 
    AMY.F_CPU_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_CPU_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_CPU_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_CPU_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_CPU_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_CPU_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_CPU_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_CPU_DAY'),
  ( select count(*) from 
    AMY.F_CPU_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_CPU_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_CPU_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_CPU_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_CPU_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_CPU_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_CPU_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_CPU_WEEK'),
  ( select count(*) from 
    AMY.F_CPU_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_CPU_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_CPU_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_CPU_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_CPU_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_CPU_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_CPU_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_CPU_MONTH'),
  ( select count(*) from 
    AMY.F_CPU_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_CPU_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_CPU_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_CPU_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_CPU_MONTH' )
;

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/ FILE FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\
-- ////////////////////////////////////////////////////////////////////////////
--
-- //////// Log the pruning of the hourly fact table AMY.F_FILE_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_FILE_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_FILE_HOUR'),
  ( select count(*) from 
    AMY.F_FILE_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_FILE_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_FILE_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_FILE_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_FILE_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_FILE_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_FILE_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_FILE_DAY'),
  ( select count(*) from 
    AMY.F_FILE_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_FILE_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_FILE_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_FILE_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_FILE_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_FILE_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_FILE_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_FILE_WEEK'),
  ( select count(*) from 
    AMY.F_FILE_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_FILE_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_FILE_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_FILE_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_FILE_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_FILE_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_FILE_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_FILE_MONTH'),
  ( select count(*) from 
    AMY.F_FILE_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_FILE_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_FILE_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_FILE_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_FILE_MONTH' )
;

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/\ FS FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////
--
-- //////// Log the pruning of the hourly fact table AMY.F_FS_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_FS_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_FS_HOUR'),
  ( select count(*) from 
    AMY.F_FS_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_FS_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_FS_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_FS_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_FS_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_FS_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_FS_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_FS_DAY'),
  ( select count(*) from 
    AMY.F_FS_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_FS_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_FS_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_FS_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_FS_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_FS_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_FS_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_FS_WEEK'),
  ( select count(*) from 
    AMY.F_FS_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_FS_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_FS_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_FS_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_FS_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_FS_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_FS_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_FS_MONTH'),
  ( select count(*) from 
    AMY.F_FS_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_FS_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_FS_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_FS_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_FS_MONTH' )
;

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/ LDISK FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--
-- //////// Log the pruning of the hourly fact table AMY.F_LDISK_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_LDISK_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_LDISK_HOUR'),
  ( select count(*) from 
    AMY.F_LDISK_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_LDISK_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_LDISK_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_LDISK_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_LDISK_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_LDISK_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_LDISK_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_LDISK_DAY'),
  ( select count(*) from 
    AMY.F_LDISK_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_LDISK_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_LDISK_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_LDISK_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_LDISK_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_LDISK_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_LDISK_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_LDISK_WEEK'),
  ( select count(*) from 
    AMY.F_LDISK_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_LDISK_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_LDISK_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_LDISK_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_LDISK_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_LDISK_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_LDISK_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_LDISK_MONTH'),
  ( select count(*) from 
    AMY.F_LDISK_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_LDISK_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_LDISK_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_LDISK_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_LDISK_MONTH' )
;

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\ PDISK FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\
-- ////////////////////////////////////////////////////////////////////////////

--
-- //////// Log the pruning of the hourly fact table AMY.F_PDISK_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PDISK_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PDISK_HOUR'),
  ( select count(*) from 
    AMY.F_PDISK_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PDISK_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_PDISK_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PDISK_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PDISK_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_PDISK_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PDISK_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PDISK_DAY'),
  ( select count(*) from 
    AMY.F_PDISK_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PDISK_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_PDISK_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PDISK_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PDISK_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_PDISK_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PDISK_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PDISK_WEEK'),
  ( select count(*) from 
    AMY.F_PDISK_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PDISK_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_PDISK_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PDISK_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PDISK_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_PDISK_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PDISK_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PDISK_MONTH'),
  ( select count(*) from 
    AMY.F_PDISK_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PDISK_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_PDISK_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PDISK_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PDISK_MONTH' )
;

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/ PROCESS FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--
-- //////// Log the pruning of the hourly fact table AMY.F_PROCESS_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PROCESS_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PROCESS_HOUR'),
  ( select count(*) from 
    AMY.F_PROCESS_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PROCESS_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_PROCESSK_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PROCESS_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PROCESS_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_PROCESS_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PROCESS_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PROCESS_DAY'),
  ( select count(*) from 
    AMY.F_PROCESS_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PROCESS_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_PROCESS_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PROCESS_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PROCESS_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_PROCESS_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PROCESS_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PROCESS_WEEK'),
  ( select count(*) from 
    AMY.F_PROCESS_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PROCESS_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_PROCESS_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PROCESS_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PROCESS_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_PROCESS_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PROCESS_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PROCESS_MONTH'),
  ( select count(*) from 
    AMY.F_PROCESS_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PROCESS_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_PROCESS_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PROCESS_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PROCESS_MONTH' )
;

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/ MEMORY FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\
-- ////////////////////////////////////////////////////////////////////////////

--
-- //////// Log the pruning of the hourly fact table AMY.F_MEMORY_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_MEMORY_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_MEMORY_HOUR'),
  ( select count(*) from 
    AMY.F_MEMORY_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_MEMORY_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_MEMORYK_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_MEMORY_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_MEMORY_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_MEMORY_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_MEMORY_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_MEMORY_DAY'),
  ( select count(*) from 
    AMY.F_MEMORY_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_MEMORY_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_MEMORY_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_MEMORY_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_MEMORY_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_MEMORY_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_MEMORY_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_MEMORY_WEEK'),
  ( select count(*) from 
    AMY.F_MEMORY_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_MEMORY_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_MEMORY_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_MEMORY_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_MEMORY_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_MEMORY_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_MEMORY_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_MEMORY_MONTH'),
  ( select count(*) from 
    AMY.F_MEMORY_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_MEMORY_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_MEMORY_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_MEMORY_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_MEMORY_MONTH' )
;

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/ NETWORK FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--
-- //////// Log the pruning of the hourly fact table AMY.F_NETWORK_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_NETWORK_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_NETWORK_HOUR'),
  ( select count(*) from 
    AMY.F_NETWORK_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_NETWORK_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_NETWORKK_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_NETWORK_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_NETWORK_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_NETWORK_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_NETWORK_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_NETWORK_DAY'),
  ( select count(*) from 
    AMY.F_NETWORK_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_NETWORK_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_NETWORK_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_NETWORK_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_NETWORK_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_NETWORK_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_NETWORK_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_NETWORK_WEEK'),
  ( select count(*) from 
    AMY.F_NETWORK_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_NETWORK_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_NETWORK_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_NETWORK_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_NETWORK_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_NETWORK_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_NETWORK_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_NETWORK_MONTH'),
  ( select count(*) from 
    AMY.F_NETWORK_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_NETWORK_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_NETWORK_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_NETWORK_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_NETWORK_MONTH' )
;

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/ PRINTER FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--
-- //////// Log the pruning of the hourly fact table AMY.F_PRINTER_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PRINTER_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PRINTER_HOUR'),
  ( select count(*) from 
    AMY.F_PRINTER_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PRINTER_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_PRINTERK_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PRINTER_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PRINTER_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_PRINTER_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PRINTER_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PRINTER_DAY'),
  ( select count(*) from 
    AMY.F_PRINTER_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PRINTER_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_PRINTER_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PRINTER_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PRINTER_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_PRINTER_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PRINTER_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PRINTER_WEEK'),
  ( select count(*) from 
    AMY.F_PRINTER_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PRINTER_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_PRINTER_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PRINTER_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PRINTER_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_PRINTER_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_PRINTER_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_PRINTER_MONTH'),
  ( select count(*) from 
    AMY.F_PRINTER_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_PRINTER_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_PRINTER_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_PRINTER_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_PRINTER_MONTH' )
;

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/ SECURITY FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\
-- ////////////////////////////////////////////////////////////////////////////

--
-- //////// Log the pruning of the hourly fact table AMY.F_SECURITY_HOUR...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_SECURITY_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_SECURITY_HOUR'),
  ( select count(*) from 
    AMY.F_SECURITY_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_SECURITY_HOUR') )
  )
;
--
-- //////// Pruning of the AMY.F_SECURITYK_HOUR hourly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_SECURITY_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_SECURITY_HOUR' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_SECURITY_DAY...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_SECURITY_DAY',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_SECURITY_DAY'),
  ( select count(*) from 
    AMY.F_SECURITY_DAY f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_SECURITY_DAY') )
  )
;
--
-- //////// Pruning of the AMY.F_SECURITY_DAY daily fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_SECURITY_DAY f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_SECURITY_DAY' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_SECURITY_WEEK...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_SECURITY_WEEK',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_SECURITY_WEEK'),
  ( select count(*) from 
    AMY.F_SECURITY_WEEK f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_SECURITY_WEEK') )
  )
;
--
-- //////// Pruning of the AMY.F_SECURITY_WEEK weekly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_SECURITY_WEEK f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_SECURITY_WEEK' )
;
--
-- //////// Log the pruning of the hourly fact table AMY.F_SECURITY_MONTH...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_SECURITY_MONTH',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_SECURITY_MONTH'),
  ( select count(*) from 
    AMY.F_SECURITY_MONTH f
    where
    ( date(current timestamp - current timezone) - date (f.meas_date) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_SECURITY_MONTH') )
  )
;
--
-- //////// Pruning of the AMY.F_SECURITY_MONTH monthly fact table...
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_SECURITY_MONTH f
where
  ( date(current timestamp - current timezone) - date(f.meas_date) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_SECURITY_MONTH' )
;

