-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amy/fixpack2/etl/sql/AMY_m05_s040_fact.db2, tmnt_etl, tmnt_5.1.1, 511ITM04C
-- #  Revision: 1.1
-- #  Date: 11/13/02 10:07:45
-- ############################################################################


-- ////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\ DATA MART FILLING SECTION /\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////


-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/ CPU FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_CPU_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_CPU_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  CPU_ID         INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, CPU_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD = 'AMY_CPU')                             
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_CPU_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD = 'AMY_CPU'
);

--
-- //////// fill the AMY.STAGE_F_CPU_HOUR fact table with CPU related measurements
-- //////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_CPU_HOUR 
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS CPU_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD = 'AMY_CPU' AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_CPU_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;
--
-- //////// copy CPU related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_CPU_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.CPU_ID, 
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_CPU_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_CPU_HOUR'
; 

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\ FILE FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_FILE_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_FILE_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FILE_ID        INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FILE_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD = 'AMY_FILE')                             
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_FILE_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD = 'AMY_FILE'
);

--
-- //////// fill the AMY.STAGE_F_FILE_HOUR fact table with File related measurements
-- //////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_FILE_HOUR 
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS FILE_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD = 'AMY_FILE' AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_FILE_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;
--
-- //////// copy File related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_FILE_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.FILE_ID, 
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_FILE_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_FILE_HOUR'
; 

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\ FS FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_FS_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_FS_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FS_ID          INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FS_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD = 'AMY_FS')                             
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_FS_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD = 'AMY_FS'
);

--
-- ///////// fill the AMY.STAGE_F_FS_HOUR fact table with File System related measurements
-- ///////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_FS_HOUR
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS FS_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD = 'AMY_FS' AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_FS_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;

--
-- //////// copy File System related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_FS_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.FS_ID,
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_FS_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_FS_HOUR'
; 

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/\ LDISK FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_LDISK_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_LDISK_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  LDISK_ID       INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, LDISK_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD = 'AMY_LDISK')                             
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_LDISK_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD = 'AMY_LDISK'
);

--
-- ///////// fill the AMY.STAGE_F_LDISK_HOUR fact table with Logical Disk related measurements
-- ///////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_LDISK_HOUR
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS LDISK_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD = 'AMY_LDISK' AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_LDISK_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;

--
-- //////// copy Logical Disk related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_LDISK_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.LDISK_ID,
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_LDISK_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_LDISK_HOUR'
; 

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/\ PDISK FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_PDISK_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_PDISK_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PDISK_ID       INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PDISK_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD = 'AMY_PDISK')                             
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_PDISK_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD = 'AMY_PDISK'
);

--
-- ///////// fill the AMY.STAGE_F_PDISK_HOUR fact table with Phisical Disk related measurements
-- ///////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_PDISK_HOUR
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS PDISK_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD = 'AMY_PDISK' AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_PDISK_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;

--
-- //////// copy Phisical Disk related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_PDISK_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.PDISK_ID,
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_PDISK_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_PDISK_HOUR'
; 

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/ PROCESS FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_PROCESS_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_PROCESS_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PROCESS_ID     INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PROCESS_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD = 'AMY_PROCESS')                             
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_PROCESS_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD = 'AMY_PROCESS'
);

--
-- ///////// fill the AMY.STAGE_F_PROCESS_HOUR fact table with Process related measurements
-- ///////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_PROCESS_HOUR
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS PROCESS_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD = 'AMY_PROCESS' AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_PROCESS_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;

--
-- //////// copy Process related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_PROCESS_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.PROCESS_ID,
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_PROCESS_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_PROCESS_HOUR'
; 

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/\ MEMORY FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_MEMORY_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_MEMORY_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  MEMORY_ID      INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, MEMORY_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD = 'AMY_MEMORY')                             
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_MEMORY_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD = 'AMY_MEMORY'
);

--
-- ///////// fill the AMY.STAGE_F_MEMORY_HOUR fact table with Memory related measurements
-- ///////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_MEMORY_HOUR
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS MEMORY_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD = 'AMY_MEMORY' AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_MEMORY_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;

--
-- //////// copy Memory related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_MEMORY_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.MEMORY_ID,
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_MEMORY_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_MEMORY_HOUR'
; 

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/\ NETWORK FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_NETWORK_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_NETWORK_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  NET_ID         INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, NET_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP'))
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_NETWORK_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP')
);

--
-- ///////// fill the AMY.STAGE_F_NETWORK_HOUR fact table with Network related measurements
-- ///////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_NETWORK_HOUR
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS NET_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP') AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_NETWORK_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;

--
-- //////// copy Network related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_NETWORK_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.NET_ID,
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_NETWORK_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_NETWORK_HOUR'
; 

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/\ PRINTER FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/\
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_PRINTER_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_PRINTER_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PRN_ID         INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PRN_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD = 'AMY_PRINTER')                             
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_PRINTER_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD = 'AMY_PRINTER'
);

--
-- ///////// fill the AMY.STAGE_F_PRINTER_HOUR fact table with Printer related measurements
-- ///////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_PRINTER_HOUR
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS PRN_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD = 'AMY_PRINTER' AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_PRINTER_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;

--
-- //////// copy Printer related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_PRINTER_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.PRN_ID,
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_PRINTER_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_PRINTER_HOUR'
; 

-- ////////////////////////////////////////////////////////////////////////////
-- /\/\/\/\/\/\/\/\/\/\/\/\/\/\ SECURITY FACT TABLE /\/\/\/\/\/\/\/\/\/\/\/\/\/
-- ////////////////////////////////////////////////////////////////////////////

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
DROP TABLE AMY.STAGE_F_SECURITY_HOUR
;

--#EXECUTE_AT_TARGET
CREATE TABLE AMY.STAGE_F_SECURITY_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  SEC_ID         INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, SEC_ID, MEAS_HOUR)
);

UPDATE TWG.EXTRACT_CONTROL SET
  EXTCTL_TO_INTSEQ = (SELECT MAX(M.MSMT_ID) 
                        FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
                       WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                              MT.MSRC_CD = 'AMY' AND
                              M.COMP_ID = C.COMP_ID AND
                              C.COMPTYP_CD IN ('AMY_USER', 'AMY_SERVER'))
WHERE 
  EXTCTL_SOURCE='TWG.MSMT' AND
  EXTCTL_TARGET='AMY.STAGE_F_SECURITY_HOUR' AND
  EXISTS (SELECT MAX(M.MSMT_ID) 
            FROM TWG.MSMT M, TWG.MSMTTYP MT, TWG.CUR_COMP C
           WHERE M.MSMTTYP_ID = MT.MSMTTYP_ID AND
                  MT.MSRC_CD = 'AMY' AND
                  M.COMP_ID = C.COMP_ID AND
                  C.COMPTYP_CD IN ('AMY_USER', 'AMY_SERVER')
);

--
-- ///////// fill the AMY.STAGE_F_SECURITY_HOUR fact table with Security related measurements
-- ///////// from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
INSERT INTO AMY.STAGE_F_SECURITY_HOUR
SELECT 
  CR.COMP_SOURCE_ID         AS HOST_ID, 
  M.MSMTTYP_ID              AS METRIC_ID, 
  M.COMP_ID                 AS SEC_ID,   
  TIMESTAMP(M.MSMT_STRT_DT, 
            M.MSMT_STRT_TM) AS MEAS_HOUR, 
  AVG(M.MSMT_MIN_VAL)       AS MIN_VALUE, 
  AVG(M.MSMT_MAX_VAL)       AS MAX_VALUE, 
  AVG(M.MSMT_AVG_VAL)       AS AVG_VALUE, 
  AVG(M.MSMT_TOT_VAL)       AS TOTAL_VALUE,
  AVG(M.MSMT_SMPL_CNT)      AS SAMPLE_COUNT
FROM  
  TWG.MSMT M,
  TWG.CUR_COMP C,
  TWG.CUR_COMPRELN CR,
  TWG.EXTRACT_CONTROL EC
WHERE  
  M.TMSUM_CD = 'H' AND
  C.COMP_ID = M.COMP_ID AND
  C.COMPTYP_CD IN ('AMY_USER', 'AMY_SERVER') AND
  CR.COMP_TARGET_ID = C.COMP_ID AND
  CR.RELNTYP_CD= 'PCHILD' AND
  EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
  EC.EXTCTL_TARGET = 'AMY.STAGE_F_SECURITY_HOUR' AND
  M.MSMT_ID > EC.EXTCTL_FROM_INTSEQ AND
  M.MSMT_ID <= EC.EXTCTL_TO_INTSEQ
GROUP BY
  M.COMP_ID, CR.COMP_SOURCE_ID, M.MSMTTYP_ID, M.MSMT_STRT_DT, M.MSMT_STRT_TM
;

--
-- //////// copy Security related measurements from staging table into hour fact table 
-- //////// at: TWH_MART
--
--#EXECUTE_AT_TARGET
INSERT INTO AMY.F_SECURITY_HOUR
SELECT
  S.HOST_ID,
  S.METRIC_ID,
  S.SEC_ID,
  S.MEAS_HOUR,
  S.MIN_VALUE,
  S.MAX_VALUE,
  S.AVG_VALUE,
  S.TOTAL_VALUE,
  S.SAMPLE_COUNT
FROM 
  AMY.STAGE_F_SECURITY_HOUR S
;
--
-- //////// confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- //////// A trigger gets fired which updates the extract control table's from 
-- //////// data with the current to data...
-- //////// at: TWH_CDW
--
INSERT INTO TWG.EXTRACT_LOG 
SELECT
 EC.EXTCTL_SOURCE,
 EC.EXTCTL_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE,
 EC.EXTCTL_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM,
 EC.EXTCTL_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'TWG.MSMT' AND
 EC.EXTCTL_TARGET = 'AMY.STAGE_F_SECURITY_HOUR'
; 

