-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amy/fixpack2/etl/sql/AMY_m10_s010_buildStarSchema.db2, tmnt_etl, tmnt_5.1.1, 511ITM04C
-- #  Revision: 1.3
-- #  Date: 12/19/02 13:32:08
-- ############################################################################

--
-- Here we perform an incremental extract using integer numbers to control
-- the extraction window; the source tables are the TWG schema tables located
-- at the CDW database (ODBC Src=TWH_CDW); the target tables are dimension and
-- fact tables located at the MART database (ODBC Tgt=TWH_MART).
--

--------------------------------------------------------------------------------
-------------------------- METRIC DIMENSION TABLES -----------------------------
--------------------------------------------------------------------------------

-------------------------
-- AMY.STAGE_D_ITM_METRIC
-------------------------

--
-- Set the high value for the data to be extracted...
--
-- at: TWH_CDW
--
update TWG.Extract_Control set 
 extctl_to_intseq = (select max(Metric_ID) from AMY.stage_d_itm_metric)
where 
 extctl_source = 'AMY.STAGE_D_ITM_METRIC' and
 extctl_target = 'AMY.D_ITM_METRIC' and
 exists ( select Metric_ID from AMY.stage_d_itm_metric )
;

--
-- Fill the Metric Dimension Table with the static data retrieved at
-- installation time and stored into the AMY.stage_d_itm_metric table...
--
-- NOTE: This process will happen only once, because we initially  
--       insert the data into the staging table in the cdw/dml script.
--
-- from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
insert into AMY.D_ITM_METRIC
select 
  d.metric_id    as metric_id,
  d.met_name     as met_name,
  d.met_desc     as met_desc,
  d.met_units    as met_units,
  d.met_category as met_category,
  d.min_exists   as min_exists,
  d.max_exists   as max_exists,
  d.avg_exists   as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm      as msrc_nm
from
  AMY.stage_d_itm_metric d,
  TWG.Extract_Control ec
where
  ec.extctl_source = 'AMY.STAGE_D_ITM_METRIC' and
  ec.extctl_target = 'AMY.D_ITM_METRIC' and
  d.metric_id > ec.extctl_from_intseq and
  d.metric_id <= ec.extctl_to_intseq 
;

--
-- Confirm the insertion of data by inserting a row into TWG.Extract_Log.
-- A trigger gets fired which updates the extract control table's from 
-- data with the current to data...
--
-- at: TWH_CDW
--
insert into TWG.Extract_Log
select
 ec.extctl_source      as extlog_source,
 ec.extctl_target      as extlog_target,
 current timestamp - 
 current timezone      as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq   as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq   as extlog_to_intseq,
 ec.extctl_from_dttm   as extlog_from_dttm,
 ec.extctl_to_dttm     as extlog_to_dttm
from 
 TWG.Extract_Control ec
where
 ec.extctl_source = 'AMY.STAGE_D_ITM_METRIC' and
 ec.extctl_target = 'AMY.D_ITM_METRIC'
;

--------------------------------------------------------------------------------
------------------------- COMPONENT DIMENSION TABLES ---------------------------
--------------------------------------------------------------------------------

-------------
-- AMY.D_HOST
-------------

--
-- Set the high value for the data to be extracted...
--
-- at: TWH_CDW 
--
update TWG.Extract_Control set 
 extctl_to_intseq = (select max(Comp_ID) 
                       from TWG.Cur_Comp
                      where CompTyp_Cd in ('IP_HOST', 'AMY_HOST', 'IP_INTERFACE'))
where 
 extctl_source = 'TWG.COMP' and
 extctl_target = 'AMY.D_HOST' and
 exists (select Comp_ID
           from TWG.Cur_Comp
          where CompTyp_Cd in ('IP_HOST', 'AMY_HOST', 'IP_INTERFACE')) 
;

--
-- Retrieve the hostname of the component IP_HOST or AMY_HOST
-- and the information about its domain, subdomain and eventually
-- second level subdomain...
--
-- from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
insert into AMY.D_HOST
select distinct co.Comp_ID   as host_id,
       co.comp_strt_dttm     as host_start_dttm,
       co.comp_end_dttm      as host_end_dttm,
       co.Comp_Nm            as hostname,
       h.network_domain      as network_domain,    
       h.network_subdomain   as network_subdomain,    
       h.network_subdomain2  as network_subdomain2,    
       h.short_hostname	     as short_hostname
  from TWG.Cur_Comp co, 
       AMY.hostname_decomp h,
       TWG.Extract_Control ec
 where co.Comp_ID = h.host_id and
       ec.extctl_source = 'TWG.COMP' and
       ec.extctl_target = 'AMY.D_HOST' and					
       co.Comp_ID > ec.extctl_from_intseq and
       co.Comp_ID <= ec.extctl_to_intseq and
       co.CompTyp_Cd in ('IP_HOST', 'AMY_HOST')
union
select distinct c1.Comp_ID as host_id,
       c1.comp_strt_dttm   as host_start_dttm,
       c1.comp_end_dttm    as host_end_dttm,
       c1.Comp_Nm          as hostname,
       'N/A'               as network_domain,
       'N/A'               as network_subdomain,    
       'N/A'               as network_subdomain2,    
       'N/A'               as short_hostname
  from TWG.Cur_Comp c1, TWG.Cur_Comp c2, TWG.CompReln cr,
       TWG.Extract_Control ec
 where c1.Comp_ID = cr.Comp_Source_ID and
       c2.Comp_ID = cr.Comp_Target_ID and
       c2.CompTyp_Cd like 'AMY%' and
       c1.CompTyp_Cd in ('IP_INTERFACE') and
       ec.extctl_source = 'TWG.COMP' and
       ec.extctl_target = 'AMY.D_HOST' and					
       c1.Comp_ID > ec.extctl_from_intseq and
       c1.Comp_ID <= ec.extctl_to_intseq
;

--
-- Confirm the insertion of data by inserting a row into TWG.Extract_Log.
-- A trigger gets fired which updates the extract control table's from 
-- data with the current to data...
--
-- at: TWH_CDW
--
insert into TWG.Extract_Log
select
 ec.extctl_source      as extlog_source,
 ec.extctl_target      as extlog_target,
 current timestamp - 
 current timezone      as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq   as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq   as extlog_to_intseq,
 ec.extctl_from_dttm   as extlog_from_dttm,
 ec.extctl_to_dttm     as extlog_to_dttm
from 
 TWG.Extract_Control ec
where
 extctl_source = 'TWG.COMP' and
 extctl_target = 'AMY.D_HOST'
; 

--------------------------------------------------------------------------------
--------------------------------- FACT TABLES ----------------------------------
--------------------------------------------------------------------------------

----------------
-- AMY.F_OS_HOUR
----------------

--
-- Prune old data from the fact table according to the values 
-- inserted into the pruning control table.
--
-- Log the pruning of the hourly fact table AMY.F_OS_HOUR...
--
-- at: TWH_MART
--
--#EXECUTE_AT_TARGET
insert into AMY.PRUNE_MART_LOG values (
  current timestamp - current timezone,
  'AMY.F_OS_HOUR',
  ( select PMartC_Duration from 
    AMY.PRUNE_MART_CONTROL
    where Table_Name='AMY.F_OS_HOUR'),
  ( select count(*) from 
    AMY.F_OS_HOUR f
    where
    ( date(current timestamp - current timezone) - date (f.meas_hour) ) >
    ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p 
      where p.Table_Name= 'AMY.F_OS_HOUR') )
  )
;

--
-- Pruning of the hourly fact table...
--
-- at: TWH_MART
--
--#EXECUTE_AT_TARGET
delete from AMY.F_OS_HOUR f
where
  ( date(current timestamp - current timezone) - date(f.meas_hour) ) >
  ( select PMartC_Duration from AMY.PRUNE_MART_CONTROL p
    where p.Table_Name = 'AMY.F_OS_HOUR' )
;

--
-- Set the high value for the data to be extracted...
--
-- at: TWH_CDW
--
update TWG.Extract_Control set 
  extctl_to_intseq = (select max(m.Msmt_ID) 
                        from TWG.Msmt m, TWG.MsmtTyp mt
                       where m.MsmtTyp_ID = mt.MsmtTyp_ID and
                             mt.Msrc_Cd = 'AMY')                             
where 
 extctl_source = 'TWG.MSMT' and
 extctl_target = 'AMY.F_OS_HOUR' and
 exists (select max(m.Msmt_ID) 
           from TWG.Msmt m, TWG.MsmtTyp mt
          where m.MsmtTyp_ID = mt.MsmtTyp_ID and
                mt.Msrc_Cd = 'AMY' )
;

--
-- Load data into the hourly fact table...
--
-- from: TWH_CDW to: TWH_MART
--
--#INSERT_INTO_TARGET
insert into AMY.F_OS_HOUR
select cr.Comp_Source_ID                          as host_id,
       m.MsmtTyp_ID                               as metric_id,
       timestamp(m.Msmt_Strt_Dt, m.Msmt_Strt_Tm)  as meas_hour,
       decimal(m.Msmt_Min_Val,18,2)               as min_value,
       decimal(m.Msmt_Max_Val,18,2)               as max_value,   
       decimal(m.Msmt_Avg_Val,18,2)               as avg_value,
       m.Msmt_Tot_Val                             as total_value,
       m.Msmt_Smpl_Cnt                            as sample_count
  from TWG.Msmt m, 
       TWG.Cur_Comp c, 
       TWG.CompReln cr,
       TWG.MsmtTyp mt,
       TWG.Extract_Control ec 
 where m.Comp_ID = cr.Comp_Target_ID and
       c.Comp_ID = cr.Comp_Source_ID and
       m.TmSum_Cd='H' and
       m.MsmtTyp_ID = mt.MsmtTyp_ID and
       mt.Msrc_Cd = 'AMY' and
       ec.extctl_source = 'TWG.MSMT' and
       ec.extctl_target = 'AMY.F_OS_HOUR' and					
       m.Msmt_ID > ec.extctl_from_intseq and
       m.Msmt_ID <= ec.extctl_to_intseq
order by timestamp(m.Msmt_Strt_Dt, m.Msmt_Strt_Tm), cr.Comp_Source_ID, m.MsmtTyp_ID
;

--
-- Confirm the insertion of data by inserting a row into TWG.Extract_Log.
-- A trigger gets fired which updates the extract control table's from 
-- data with the current to data...
--
-- at: TWH_CDW
--
insert into TWG.Extract_Log
select
 ec.extctl_source      as extlog_source,
 ec.extctl_target      as extlog_target,
 current timestamp - 
 current timezone      as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq   as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq   as extlog_to_intseq,
 ec.extctl_from_dttm   as extlog_from_dttm,
 ec.extctl_to_dttm     as extlog_to_dttm
from 
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'AMY.F_OS_HOUR'
; 
