-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amy/fixpack2/mart/ddl/amy_mart_schema.sql, tmnt_etl, tmnt_5.1.1_FP04
-- #  Revision: 1.1
-- #  Date: 11/13/02 10:08:04
-- ############################################################################

--
-- NOTE: the base AMY enablement only creates general purpose fact and dimension
-- tables:
-- 
--   - AMY.D_ITM_METRIC: metric dimension table that stores all 
--                       metrics evaluated by the ITM resource models;
--
--   - AMY.D_HOST: dimension table that stores basic informations about 
--                 the monitored hosts
--
--   - AMY.F_OS_HOUR: hourly fact table that stores the "facts" for all 
--                    metrics and hosts
--
-- This approach doesn't allow an instance level reporting, so we need a new
-- dimension table to account the different instances of a monitored resource
-- and different fact tables for each resource; moreover, for a better user 
-- experience with the TEDW reporting interface, we define resource specific 
-- metric dimension tables; i.e. we define a metric dimension table for each
-- Measurement Group defined for the 'ITM' Measurement Group Type.
--
--               CPU: for CPU and Process related metrics (CPU_E); 
--       File System: for File and File System related metrics (FS_E);
--               I/O: for Disk I/O related metrics (HD_E);
--            Memory: for Memory related metrics (MEM_E);
-- Network Interface: for Network related metrics (NIC_E);
--           Printer: for Printer related metrics (PRN_E);
--          Security: for Security related metrics (SEC_E);
--

--#iftag fixpack_400

-----------------------------
-- METRIC DIMENSION TABLES --
-----------------------------

--
-- create the AMY.D_CPU_METRIC metric dimension table for CPU (Processor) 
-- and Process related metrics...
--
CREATE TABLE AMY.D_CPU_METRIC (
  METRIC_ID      INTEGER      NOT NULL,
  MET_NAME       VARCHAR(254) NOT NULL,
  MET_DESC       VARCHAR(254) NOT NULL,
  MET_UNITS      VARCHAR(254) NOT NULL,
  MET_CATEGORY   VARCHAR(254) NOT NULL,
  MSRC_NM        VARCHAR(254) NOT NULL,
  MIN_EXISTS     CHAR(1)      NOT NULL,
  MAX_EXISTS     CHAR(1)      NOT NULL,
  AVG_EXISTS     CHAR(1)      NOT NULL,
  TOTAL_EXISTS   CHAR(1)      NOT NULL,     
    PRIMARY KEY (METRIC_ID)
);

--
-- create the AMY.D_FS_METRIC metric dimension table for File and Files 
-- System related metrics...
--
CREATE TABLE AMY.D_FS_METRIC (
  METRIC_ID      INTEGER      NOT NULL,
  MET_NAME       VARCHAR(254) NOT NULL,
  MET_DESC       VARCHAR(254) NOT NULL,
  MET_UNITS      VARCHAR(254) NOT NULL,
  MET_CATEGORY   VARCHAR(254) NOT NULL,
  MSRC_NM        VARCHAR(254) NOT NULL,
  MIN_EXISTS     CHAR(1)      NOT NULL,
  MAX_EXISTS     CHAR(1)      NOT NULL,
  AVG_EXISTS     CHAR(1)      NOT NULL,
  TOTAL_EXISTS   CHAR(1)      NOT NULL,     
    PRIMARY KEY (METRIC_ID)
);

--
-- create the AMY.D_IO_METRIC metric dimension table for Disk I/O 
-- related metrics...
--
CREATE TABLE AMY.D_IO_METRIC (
  METRIC_ID      INTEGER      NOT NULL,
  MET_NAME       VARCHAR(254) NOT NULL,
  MET_DESC       VARCHAR(254) NOT NULL,
  MET_UNITS      VARCHAR(254) NOT NULL,
  MET_CATEGORY   VARCHAR(254) NOT NULL,
  MSRC_NM        VARCHAR(254) NOT NULL,
  MIN_EXISTS     CHAR(1)      NOT NULL,
  MAX_EXISTS     CHAR(1)      NOT NULL,
  AVG_EXISTS     CHAR(1)      NOT NULL,
  TOTAL_EXISTS   CHAR(1)      NOT NULL,     
    PRIMARY KEY (METRIC_ID)
);

--
-- create the AMY.D_MEM_METRIC metric dimension table for Memory 
-- related metrics...
--
CREATE TABLE AMY.D_MEM_METRIC (
  METRIC_ID      INTEGER      NOT NULL,
  MET_NAME       VARCHAR(254) NOT NULL,
  MET_DESC       VARCHAR(254) NOT NULL,
  MET_UNITS      VARCHAR(254) NOT NULL,
  MET_CATEGORY   VARCHAR(254) NOT NULL,
  MSRC_NM        VARCHAR(254) NOT NULL,
  MIN_EXISTS     CHAR(1)      NOT NULL,
  MAX_EXISTS     CHAR(1)      NOT NULL,
  AVG_EXISTS     CHAR(1)      NOT NULL,
  TOTAL_EXISTS   CHAR(1)      NOT NULL,     
    PRIMARY KEY (METRIC_ID)
);

--
-- create the AMY.D_NET_METRIC metric dimension table for Network 
-- related metrics...
--
CREATE TABLE AMY.D_NET_METRIC (
  METRIC_ID      INTEGER      NOT NULL,
  MET_NAME       VARCHAR(254) NOT NULL,
  MET_DESC       VARCHAR(254) NOT NULL,
  MET_UNITS      VARCHAR(254) NOT NULL,
  MET_CATEGORY   VARCHAR(254) NOT NULL,
  MSRC_NM        VARCHAR(254) NOT NULL,
  MIN_EXISTS     CHAR(1)      NOT NULL,
  MAX_EXISTS     CHAR(1)      NOT NULL,
  AVG_EXISTS     CHAR(1)      NOT NULL,
  TOTAL_EXISTS   CHAR(1)      NOT NULL,     
    PRIMARY KEY (METRIC_ID)
);

--
-- create the AMY.D_PRN_METRIC metric dimension table for Printer 
-- related metrics...
--
CREATE TABLE AMY.D_PRN_METRIC (
  METRIC_ID      INTEGER      NOT NULL,
  MET_NAME       VARCHAR(254) NOT NULL,
  MET_DESC       VARCHAR(254) NOT NULL,
  MET_UNITS      VARCHAR(254) NOT NULL,
  MET_CATEGORY   VARCHAR(254) NOT NULL,
  MSRC_NM        VARCHAR(254) NOT NULL,
  MIN_EXISTS     CHAR(1)      NOT NULL,
  MAX_EXISTS     CHAR(1)      NOT NULL,
  AVG_EXISTS     CHAR(1)      NOT NULL,
  TOTAL_EXISTS   CHAR(1)      NOT NULL,     
    PRIMARY KEY (METRIC_ID)
);

--
-- create the AMY.D_SEC_METRIC metric dimension table for Security 
-- related metrics...
--
CREATE TABLE AMY.D_SEC_METRIC (
  METRIC_ID      INTEGER      NOT NULL,
  MET_NAME       VARCHAR(254) NOT NULL,
  MET_DESC       VARCHAR(254) NOT NULL,
  MET_UNITS      VARCHAR(254) NOT NULL,
  MET_CATEGORY   VARCHAR(254) NOT NULL,
  MSRC_NM        VARCHAR(254) NOT NULL,
  MIN_EXISTS     CHAR(1)      NOT NULL,
  MAX_EXISTS     CHAR(1)      NOT NULL,
  AVG_EXISTS     CHAR(1)      NOT NULL,
  TOTAL_EXISTS   CHAR(1)      NOT NULL,     
    PRIMARY KEY (METRIC_ID)
);


--------------------------------
-- COMPONENT DIMENSION TABLES --
--------------------------------

--
-- create the dimension table for AMY_HOSTs and/or IP_HOSTs 
--
CREATE TABLE AMY.D_HOST_IP (
  HOST_ID             INTEGER      NOT NULL,
  HOST_START_DTTM     TIMESTAMP,
  HOST_END_DTTM       TIMESTAMP,
  HOSTNAME            VARCHAR(120) NOT NULL,
  NETWORK_DOMAIN      VARCHAR(120),
  NETWORK_SUBDOMAIN   VARCHAR(120),
  NETWORK_SUBDOMAIN2  VARCHAR(120),
  SHORT_HOSTNAME      VARCHAR(64)  NOT NULL,
  LAST_IP_ADDRESS     VARCHAR(20),
  CUSTOMER_NAME       VARCHAR(120),
  CENTER_NAME         VARCHAR(120),
    PRIMARY KEY (HOST_ID)
);

--
-- create the AMY.D_CPU dimension table for the monitored CPUs
--
CREATE TABLE AMY.D_CPU (
  CPU_ID    INTEGER      NOT NULL,
  CPU_NM    VARCHAR(254) NOT NULL,
    PRIMARY KEY (CPU_ID)
);

--
-- create the AMY.D_FILE dimension table for the monitored Files
--
CREATE TABLE AMY.D_FILE (
  FILE_ID          INTEGER      NOT NULL,
  FILE_NAME        VARCHAR(254) NOT NULL,
  FILE_OWNER       VARCHAR(120),
  FILE_PERMISSIONS VARCHAR(15), 
  FILE_GROUP       VARCHAR(120),
    PRIMARY KEY (FILE_ID)
);

--
-- create the AMY.D_FS dimension table for the monitored File Systems
--
CREATE TABLE AMY.D_FS (
  FS_ID            INTEGER      NOT NULL,
  FS_MOUNTPOINT    VARCHAR(254) NOT NULL,
    PRIMARY KEY (FS_ID)
);

--
-- create the AMY.D_LDISK dimension table for the monitored Logical Disks
--
CREATE TABLE AMY.D_LDISK (
  LDISK_ID    INTEGER      NOT NULL,
  LDISK_NM    VARCHAR(254) NOT NULL,
    PRIMARY KEY (LDISK_ID)
);

--
-- create the AMY.D_PDISK dimension table for the monitored Phisical Disks
--
CREATE TABLE AMY.D_PDISK (
  PDISK_ID    INTEGER      NOT NULL,
  PDISK_NM    VARCHAR(254) NOT NULL,
    PRIMARY KEY (PDISK_ID)
);

--
-- create the AMY.D_PROCESS dimension table for the monitored Processes
--
CREATE TABLE AMY.D_PROCESS (
  PROCESS_ID   INTEGER      NOT NULL,
  PROC_NM      VARCHAR(254) NOT NULL,
  PROC_ID      VARCHAR(16)  NOT NULL,
    PRIMARY KEY (PROCESS_ID)
);

--
-- create the AMY.D_MEMORY dimension table for the monitored Memory
--
CREATE TABLE AMY.D_MEMORY (
  MEMORY_ID   INTEGER      NOT NULL,
  MEMORY_NM   VARCHAR(254) NOT NULL,
    PRIMARY KEY (MEMORY_ID)
);

--
-- create the AMY.D_NETWORK dimension table for the monitored Network Interface
--
CREATE TABLE AMY.D_NETWORK (
  NET_ID   INTEGER      NOT NULL,
  NET_NM   VARCHAR(254) NOT NULL,
    PRIMARY KEY (NET_ID)
);

--
-- create the AMY.D_PRINTER dimension table for the monitored Printers
--
CREATE TABLE AMY.D_PRINTER (
  PRN_ID   INTEGER      NOT NULL,
  PRN_NM   VARCHAR(254) NOT NULL,
    PRIMARY KEY (PRN_ID)
);

--
-- create the AMY.D_SECURITY dimension table for the monitored Security parameters
--
CREATE TABLE AMY.D_SECURITY (
  SEC_ID   INTEGER      NOT NULL,
  SEC_NM   VARCHAR(254) NOT NULL,
    PRIMARY KEY (SEC_ID)
);

------------------------
-- HOURLY FACT TABLES --
------------------------

--
-- hourly fact table for CPU related metrics
--
CREATE TABLE AMY.F_CPU_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  CPU_ID         INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, CPU_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_CPU_HOUR
    ADD CONSTRAINT FK_F_CPU_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_CPU_HR_1 ON AMY.F_CPU_HOUR (HOST_ID);

ALTER TABLE AMY.F_CPU_HOUR
    ADD CONSTRAINT FK_F_CPU_HR_D_MET FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_CPU_METRIC (METRIC_ID);

CREATE INDEX IDX_F_CPU_HR_2 ON AMY.F_CPU_HOUR (METRIC_ID);

ALTER TABLE AMY.F_CPU_HOUR
    ADD CONSTRAINT FK_F_CPU_HR_D_CPU FOREIGN KEY (CPU_ID) REFERENCES AMY.D_CPU (CPU_ID);

CREATE INDEX IDX_F_CPU_HR_3 ON AMY.F_CPU_HOUR (CPU_ID);

--
-- hourly fact table for File related metrics
--
CREATE TABLE AMY.F_FILE_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FILE_ID        INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FILE_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_FILE_HOUR
    ADD CONSTRAINT FK_F_FILE_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_FILE_HR_1 ON AMY.F_FILE_HOUR (HOST_ID);

ALTER TABLE AMY.F_FILE_HOUR
    ADD CONSTRAINT FK_F_FL_HR_D_FS_M FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_FS_METRIC (METRIC_ID);

CREATE INDEX IDX_F_FILE_HR_2 ON AMY.F_FILE_HOUR (METRIC_ID);

ALTER TABLE AMY.F_FILE_HOUR
    ADD CONSTRAINT FK_F_FL_HR_D_FL FOREIGN KEY (FILE_ID) REFERENCES AMY.D_FILE (FILE_ID);

CREATE INDEX IDX_F_FILE_HR_3 ON AMY.F_FILE_HOUR (FILE_ID);

--
-- hourly fact table for File System related metrics
--
CREATE TABLE AMY.F_FS_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FS_ID          INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FS_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_FS_HOUR
    ADD CONSTRAINT FK_F_FS_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_FS_HR_1 ON AMY.F_FS_HOUR (HOST_ID);

ALTER TABLE AMY.F_FS_HOUR
    ADD CONSTRAINT FK_F_FS_HR_D_FS_M FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_FS_METRIC (METRIC_ID);

CREATE INDEX IDX_F_FS_HR_2 ON AMY.F_FS_HOUR (METRIC_ID);

ALTER TABLE AMY.F_FS_HOUR
    ADD CONSTRAINT FK_F_FS_HR_D_FS FOREIGN KEY (FS_ID) REFERENCES AMY.D_FS (FS_ID);

CREATE INDEX IDX_F_FS_HR_3 ON AMY.F_FS_HOUR (FS_ID);

--
-- hourly fact table for Logical Disk related metrics
--
CREATE TABLE AMY.F_LDISK_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  LDISK_ID       INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, LDISK_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_LDISK_HOUR
    ADD CONSTRAINT FK_F_LDSK_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_LDSK_HR_1 ON AMY.F_LDISK_HOUR (HOST_ID);

ALTER TABLE AMY.F_LDISK_HOUR
    ADD CONSTRAINT FK_F_LDSK_HR_D_MET FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_IO_METRIC (METRIC_ID);

CREATE INDEX IDX_F_LDSK_HR_2 ON AMY.F_LDISK_HOUR (METRIC_ID);

ALTER TABLE AMY.F_LDISK_HOUR
    ADD CONSTRAINT FK_F_LDSK_HR_D_LD FOREIGN KEY (LDISK_ID) REFERENCES AMY.D_LDISK (LDISK_ID);

CREATE INDEX IDX_F_LDSK_HR_3 ON AMY.F_LDISK_HOUR (LDISK_ID);

--
-- hourly fact table for Phisical Disk related metrics
--
CREATE TABLE AMY.F_PDISK_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PDISK_ID       INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PDISK_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_PDISK_HOUR
    ADD CONSTRAINT FK_F_PDSK_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_PDSK_HR_1 ON AMY.F_PDISK_HOUR (HOST_ID);

ALTER TABLE AMY.F_PDISK_HOUR
    ADD CONSTRAINT FK_F_PDSK_HR_D_MET FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_IO_METRIC (METRIC_ID);

CREATE INDEX IDX_F_PDSK_HR_2 ON AMY.F_PDISK_HOUR (METRIC_ID);

ALTER TABLE AMY.F_PDISK_HOUR
    ADD CONSTRAINT FK_F_PDSK_HR_D_LD FOREIGN KEY (PDISK_ID) REFERENCES AMY.D_PDISK (PDISK_ID);

CREATE INDEX IDX_F_PDSK_HR_3 ON AMY.F_PDISK_HOUR (PDISK_ID);

--
-- hourly fact table for Process related metrics
--
CREATE TABLE AMY.F_PROCESS_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PROCESS_ID     INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PROCESS_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_PROCESS_HOUR
    ADD CONSTRAINT FK_F_PROC_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_PROC_HR_1 ON AMY.F_PROCESS_HOUR (HOST_ID);

ALTER TABLE AMY.F_PROCESS_HOUR
    ADD CONSTRAINT FK_F_PR_HR_D_CPM FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_CPU_METRIC (METRIC_ID);

CREATE INDEX IDX_F_PROC_HR_2 ON AMY.F_PROCESS_HOUR (METRIC_ID);

ALTER TABLE AMY.F_PROCESS_HOUR
    ADD CONSTRAINT FK_F_PR_HR_D_PR FOREIGN KEY (PROCESS_ID) REFERENCES AMY.D_PROCESS (PROCESS_ID);

CREATE INDEX IDX_F_PROC_HR_3 ON AMY.F_PROCESS_HOUR (PROCESS_ID);

--
-- hourly fact table for Memory related metrics
--
CREATE TABLE AMY.F_MEMORY_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  MEMORY_ID      INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, MEMORY_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_MEMORY_HOUR
    ADD CONSTRAINT FK_F_MEM_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_MEM_HR_1 ON AMY.F_MEMORY_HOUR (HOST_ID);

ALTER TABLE AMY.F_MEMORY_HOUR
    ADD CONSTRAINT FK_F_MEM_HR_D_M_M FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_MEM_METRIC (METRIC_ID);

CREATE INDEX IDX_F_MEM_HR_2 ON AMY.F_MEMORY_HOUR (METRIC_ID);

ALTER TABLE AMY.F_MEMORY_HOUR
    ADD CONSTRAINT FK_F_MEM_HR_D_MEM FOREIGN KEY (MEMORY_ID) REFERENCES AMY.D_MEMORY (MEMORY_ID);

CREATE INDEX IDX_F_MEM_HR_3 ON AMY.F_MEMORY_HOUR (MEMORY_ID);

--
-- hourly fact table for Network related metrics
--
CREATE TABLE AMY.F_NETWORK_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  NET_ID         INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, NET_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_NETWORK_HOUR
    ADD CONSTRAINT FK_F_NET_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_NET_HR_1 ON AMY.F_NETWORK_HOUR (HOST_ID);

ALTER TABLE AMY.F_NETWORK_HOUR
    ADD CONSTRAINT FK_F_NET_HR_D_MET FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_NET_METRIC (METRIC_ID);

CREATE INDEX IDX_F_NET_HR_2 ON AMY.F_NETWORK_HOUR (METRIC_ID);

ALTER TABLE AMY.F_NETWORK_HOUR
    ADD CONSTRAINT FK_F_NET_HR_D_NET FOREIGN KEY (NET_ID) REFERENCES AMY.D_NETWORK (NET_ID);

CREATE INDEX IDX_F_NET_HR_3 ON AMY.F_NETWORK_HOUR (NET_ID);

--
-- hourly fact table for Printer related metrics
--
CREATE TABLE AMY.F_PRINTER_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PRN_ID         INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PRN_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_PRINTER_HOUR
    ADD CONSTRAINT FK_F_PRN_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_PRN_HR_1 ON AMY.F_PRINTER_HOUR (HOST_ID);

ALTER TABLE AMY.F_PRINTER_HOUR
    ADD CONSTRAINT FK_F_PRN_HR_D_MET FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_PRN_METRIC (METRIC_ID);

CREATE INDEX IDX_F_PRN_HR_2 ON AMY.F_PRINTER_HOUR (METRIC_ID);

ALTER TABLE AMY.F_PRINTER_HOUR
    ADD CONSTRAINT FK_F_PRN_HR_D_PRN FOREIGN KEY (PRN_ID) REFERENCES AMY.D_PRINTER (PRN_ID);

CREATE INDEX IDX_F_PRN_HR_3 ON AMY.F_PRINTER_HOUR (PRN_ID);

--
-- hourly fact table for Security related metrics
--
CREATE TABLE AMY.F_SECURITY_HOUR (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  SEC_ID         INTEGER   NOT NULL,
  MEAS_HOUR      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, SEC_ID, MEAS_HOUR)
);

ALTER TABLE AMY.F_SECURITY_HOUR
    ADD CONSTRAINT FK_F_SEC_HR_D_HST FOREIGN KEY (HOST_ID) REFERENCES AMY.D_HOST_IP (HOST_ID);

CREATE INDEX IDX_F_SEC_HR_1 ON AMY.F_SECURITY_HOUR (HOST_ID);

ALTER TABLE AMY.F_SECURITY_HOUR
    ADD CONSTRAINT FK_F_SEC_HR_D_MET FOREIGN KEY (METRIC_ID) REFERENCES AMY.D_SEC_METRIC (METRIC_ID);

CREATE INDEX IDX_F_SEC_HR_2 ON AMY.F_SECURITY_HOUR (METRIC_ID);

ALTER TABLE AMY.F_SECURITY_HOUR
    ADD CONSTRAINT FK_F_SEC_HR_D_SEC FOREIGN KEY (SEC_ID) REFERENCES AMY.D_SECURITY (SEC_ID);

CREATE INDEX IDX_F_SEC_HR_3 ON AMY.F_SECURITY_HOUR (SEC_ID);


-----------------------
-- DAILY FACT TABLES --
-----------------------

--
-- daily fact table for CPU related metrics
--
CREATE TABLE AMY.F_CPU_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  CPU_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, CPU_ID, MEAS_DATE)
);

--
-- daily fact table for File related metrics
--
CREATE TABLE AMY.F_FILE_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FILE_ID        INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FILE_ID, MEAS_DATE)
);

--
-- daily fact table for File System related metrics
--
CREATE TABLE AMY.F_FS_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FS_ID          INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FS_ID, MEAS_DATE)
);

--
-- daily fact table for Logical Disk related metrics
--
CREATE TABLE AMY.F_LDISK_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  LDISK_ID       INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, LDISK_ID, MEAS_DATE)
);

--
-- daily fact table for Phisical Disk related metrics
--
CREATE TABLE AMY.F_PDISK_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PDISK_ID       INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PDISK_ID, MEAS_DATE)
);

--
-- daily fact table for Process related metrics
--
CREATE TABLE AMY.F_PROCESS_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PROCESS_ID     INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PROCESS_ID, MEAS_DATE)
);

--
-- daily fact table for Memory related metrics
--
CREATE TABLE AMY.F_MEMORY_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  MEMORY_ID      INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, MEMORY_ID, MEAS_DATE)
);

--
-- daily fact table for Network related metrics
--
CREATE TABLE AMY.F_NETWORK_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  NET_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, NET_ID, MEAS_DATE)
);

--
-- daily fact table for Printer related metrics
--
CREATE TABLE AMY.F_PRINTER_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PRN_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PRN_ID, MEAS_DATE)
);

--
-- daily fact table for Security related metrics
--
CREATE TABLE AMY.F_SECURITY_DAY (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  SEC_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, SEC_ID, MEAS_DATE)
);

------------------------
-- WEEKLY FACT TABLES --
------------------------

--
-- weekly fact table for CPU related metrics
--
CREATE TABLE AMY.F_CPU_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  CPU_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, CPU_ID, MEAS_DATE)
);

--
-- weekly fact table for File related metrics
--
CREATE TABLE AMY.F_FILE_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FILE_ID        INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FILE_ID, MEAS_DATE)
);

--
-- weekly fact table for File System related metrics
--
CREATE TABLE AMY.F_FS_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FS_ID          INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FS_ID, MEAS_DATE)
);

--
-- weekly fact table for Logical Disk related metrics
--
CREATE TABLE AMY.F_LDISK_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  LDISK_ID       INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, LDISK_ID, MEAS_DATE)
);

--
-- weekly fact table for Phisical Disk related metrics
--
CREATE TABLE AMY.F_PDISK_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PDISK_ID       INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PDISK_ID, MEAS_DATE)
);

--
-- weekly fact table for Process related metrics
--
CREATE TABLE AMY.F_PROCESS_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PROCESS_ID     INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PROCESS_ID, MEAS_DATE)
);

--
-- weekly fact table for Memory related metrics
--
CREATE TABLE AMY.F_MEMORY_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  MEMORY_ID      INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, MEMORY_ID, MEAS_DATE)
);

--
-- weekly fact table for Network related metrics
--
CREATE TABLE AMY.F_NETWORK_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  NET_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, NET_ID, MEAS_DATE)
);

--
-- weekly fact table for Printer related metrics
--
CREATE TABLE AMY.F_PRINTER_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PRN_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PRN_ID, MEAS_DATE)
);

--
-- weekly fact table for Security related metrics
--
CREATE TABLE AMY.F_SECURITY_WEEK (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  SEC_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, SEC_ID, MEAS_DATE)
);

-------------------------
-- MONTHLY FACT TABLES --
-------------------------

--
-- monthly fact table for CPU related metrics
--
CREATE TABLE AMY.F_CPU_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  CPU_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, CPU_ID, MEAS_DATE)
);

--
-- monthly fact table for File related metrics
--
CREATE TABLE AMY.F_FILE_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FILE_ID        INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FILE_ID, MEAS_DATE)
);

--
-- monthly fact table for File System related metrics
--
CREATE TABLE AMY.F_FS_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  FS_ID          INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, FS_ID, MEAS_DATE)
);

--
-- monthly fact table for Logical Disk related metrics
--
CREATE TABLE AMY.F_LDISK_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  LDISK_ID       INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, LDISK_ID, MEAS_DATE)
);

--
-- monthly fact table for Phisical Disk related metrics
--
CREATE TABLE AMY.F_PDISK_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PDISK_ID       INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PDISK_ID, MEAS_DATE)
);

--
-- monthly fact table for Process related metrics
--
CREATE TABLE AMY.F_PROCESS_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PROCESS_ID     INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PROCESS_ID, MEAS_DATE)
);

--
-- monthly fact table for Memory related metrics
--
CREATE TABLE AMY.F_MEMORY_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  MEMORY_ID      INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, MEMORY_ID, MEAS_DATE)
);

--
-- monthly fact table for Network related metrics
--
CREATE TABLE AMY.F_NETWORK_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  NET_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, NET_ID, MEAS_DATE)
);

--
-- monthly fact table for Printer related metrics
--
CREATE TABLE AMY.F_PRINTER_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  PRN_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, PRN_ID, MEAS_DATE)
);

--
-- monthly fact table for Security related metrics
--
CREATE TABLE AMY.F_SECURITY_MONTH (
  HOST_ID        INTEGER   NOT NULL,
  METRIC_ID      INTEGER   NOT NULL,
  SEC_ID         INTEGER   NOT NULL,
  MEAS_DATE      TIMESTAMP NOT NULL,
  MIN_VALUE      FLOAT,
  MAX_VALUE      FLOAT,
  AVG_VALUE      FLOAT,
  TOTAL_VALUE    FLOAT,
  SAMPLE_COUNT   INTEGER,
    PRIMARY KEY (HOST_ID, METRIC_ID, SEC_ID, MEAS_DATE)
);

-----------------------------------------------
-- STAGING TABLES USED BY THE ROLLUP PROCESS -- 
-----------------------------------------------

--
-- stage hourly fact table for CPU related metrics
--
CREATE TABLE AMY.STAGE_F_CPU_HOUR LIKE AMY.F_CPU_HOUR;
--
-- stage hourly fact table for File related metrics
--
CREATE TABLE AMY.STAGE_F_FILE_HOUR LIKE AMY.F_FILE_HOUR;
--
-- stage hourly fact table for File System related metrics
--
CREATE TABLE AMY.STAGE_F_FS_HOUR LIKE AMY.F_FS_HOUR;
--
-- stage hourly fact table for Logical Disk related metrics
--
CREATE TABLE AMY.STAGE_F_LDISK_HOUR LIKE AMY.F_LDISK_HOUR;
--
-- stage hourly fact table for Phisical Disk related metrics
--
CREATE TABLE AMY.STAGE_F_PDISK_HOUR LIKE AMY.F_PDISK_HOUR;
--
-- stage hourly fact table for Process related metrics
--
CREATE TABLE AMY.STAGE_F_PROCESS_HOUR LIKE AMY.F_PROCESS_HOUR;
--
-- stage hourly fact table for Memory related metrics
--
CREATE TABLE AMY.STAGE_F_MEMORY_HOUR LIKE AMY.F_MEMORY_HOUR;
--
-- stage hourly fact table for Network related metrics
--
CREATE TABLE AMY.STAGE_F_NETWORK_HOUR LIKE AMY.F_NETWORK_HOUR;
--
-- stage hourly fact table for Printer related metrics
--
CREATE TABLE AMY.STAGE_F_PRINTER_HOUR LIKE AMY.F_PRINTER_HOUR;
--
-- stage hourly fact table for Printer related metrics
--
CREATE TABLE AMY.STAGE_F_SECURITY_HOUR LIKE AMY.F_SECURITY_HOUR;

--#endtag fixpack_400
